function c = lbl2cell(x,y,K)
% LBL2CELL - convert labels data into cell array of data with the same label
%
%   c=lbl2cell(x,labels) return a cell array of size the number of different
%   labels.
%   [c,labs]=lbl2cell(x,labels) also return labels in the same order as in
%   the returned cell array c
%
%   NOTE lbl2cell and cell2lbl are not strictly equivalent (due to the dimensiosn shifts)
%  
%   See also CELL2LBL

if nargin==1
    c = cell(1,max(x));
    for i=1:length(c)
        c{i} = find(x==i);
    end
    return
end

if nargin<3
    y = y-min(y)+1;
    K = max(y);
end

c = cell(1,K);
if ndims(x)==3
    for k=1:K
        c{k} = x(:,:,find(y==k));
    end
elseif ndims(x)==4
    for k=1:K
        c{k} = x(:,:,:,find(y==k));
    end
else
    for k=1:K
        c{k} = x(find(y==k),:);
    end
end