function [c,ind,scores] = learncl_and_select(carray,x,cl,scoretype,varargin)
% LEARNCL_AND_SELECT - Learn multiple classifier models and select the best
%
% c = LEARNCL_AND_SELECT(carray,x,cl)
% c = LEARNCL_AND_SELECT(carray,x,cl,CV) CV is a interger value
% c = LEARNCL_AND_SELECT(carray,x,cl,scoretype) score type is a string (currently 'bic' or 'bec')
%   multiple scores can be given in a cell array
%
% [c,scores] = LEARNCL_AND_SELECT(carray,x,cl,scoretype)
% [c,scores] = LEARNCL_AND_SELECT(carray,x,cl,scoretype,'argname',argvalue,...)
%
% See also CLASSIFIER/LEARN, DENSITY/BIC_SCORE
%   STATLEARN

[n,d]=size(x);
if nargin<4
    scoretype = min(n,1+ceil(1000/n));
end

if ~iscell(scoretype)
    scoretype = {scoretype};
end

ns = length(scoretype);

nmod = length(carray);

scores = zeros(ns,nmod);
c={};
for st=1:ns
    if isnumeric(scoretype{st})
        scores(st,:) = mean(eval_errCV(classifier,carray,x,cl,scoretype{st}));
    else
        if isempty(c);
            c = learn(carray,x,cl);    
        end
        eval(['scores(st,:) = ' scoretype{st} '_score(c,x,cl);']);
    end
end

[mini,ind]=min(scores,[],2);    
uind = unique(ind);
if isempty(c)
    c = cell(1,nmod);
    c(uind) = learn(carray(uind),x,cl);
end
