function [h,nli,nco] = show(carray,dims,varargin)
%SHOW plot a cell array of 3D distributions or classifiers
%
% SHOW(carray,...)
% calls the method 'show3' in subplots for each object of carray
%
% SHOW(carray,...,'titles',tarray,...)
% add the titles included in the cell array tarray
%
% SHOW(carray,...,'lims',[minx,maxx,miny,maxy,minz,maxz],...)
% set common limits
% 
% Remaining arguments are passed to the methods SHOW applied on 
% individual classifiers or densities
%
% SHOW(carray,[nrows,ncols],...)
% The number of lines and row of subplots can be specified in nrows and 
% ncols
%
% h = SHOW(carray,...) returns a cell array of handles to graphical
% objects (returned by the different show methods)
%
% [h,nrows,ncol] = SHOW(carray,...) returns the number of rows and columns 
% that are used to draw the pictures with subplot
%
% See also DENSITY/SHOW, CLASSIFIER/SHOW, COLPLOT

L = length(carray);

if nargin<2 | ~isnumeric(dims) | length(dims)~=2
    nli  = ceil(sqrt(L));
    nco = ceil(L/nli);
    if nargin>=2
        varargin={dims,varargin{:}};
    end
else
    nli  = dims(1);
    nco = dims(2);
end 

titles={};
    
if ~isempty(varargin) & ~isstr(varargin{1})
    if length(varargin)>=2 & ~isstr(varargin{2})
        varargin={varargin{3:end},'x',varargin{1},'cl',varargin{2}};
    else
        varargin={varargin{2:end},'x',varargin{1}};
    end
end


titles=[];
lims=[];
vararginrem = {};
%%% PARAMETERS MANAGEMENT
if ~isempty(varargin) & iscell(varargin{1}),varargin=varargin{1};end
for i=1:2:length(varargin)
    if ~isstr(varargin{i}) | ~exist(varargin{i},'var')
          vararginrem=varargin(i:end);break;
    end
    eval([varargin{i} '= varargin{i+1};']);
end
%%%
lims=lims(:);


nc = length(carray(:));
h=cell(1,nc);
for i=1:nc
    subplot(nli,nco,i);
    h{i} = show(carray{i},vararginrem);
    if ~isempty(titles)
        title(titles{i});
    end
    if ~isempty(lims)
        set(gca,'XLim',lims(1:2),'YLim',lims(3:4),'ZLim',lims(5:6))
    end
end
h = reshape(h,size(carray));

if nargout<1
    clear h
end
