function c = DENSITYCL_EXAMPLE
% DENSITYCL_EXAMPLE - Example of classification based on density estimation
%
% c = DENSITYCL_EXAMPLE returns a densitycl object:
%   - the distribution of the group 1 is a gaussian distribution
%   - the distribution of the group 2 is a mixture of 2 gaussian distributions
%
% DENSITYCL_EXAMPLE (without output argument) plots the classifier with
%   a random sample
%
% See also DENSITYCL, CLASSIFIER, MIXTDENS_EXAMPLE, MIXTDENS
%   SLDEMOS
%   UNSUPERVISED, STATLEARN

d1 = gaussdens('m',[1 2],'var',[.25 -.25;-.25 1.25]);
d2 = mixtdens({...,
        gaussdens('m',[0 0],'var',[1 -1;-1 1.25]),...
        gaussdens('m',[2 0],'var',[.25 .25;.25 .5]),...
    },'p',[.6 .4]);

c = densitycl({d1,d2},'p',[.4 .6]);

if nargout==0
    figure
    [x,cl] = rand(c,300);
    show(c,x,cl);
    title('DensityCl example');
end