function slide = gaussdens_slideshow
% GAUSSDENS_SLIDESHOW - How to use gaussian distribution objects
% 
% 
% Copyright Guillaume Bouchard, 2004
if nargout<1,
  playshow densitydemo
else
  %========== Slide 1 ==========

  slide(1).code={
   'cla;',
   'gen=gaussdens(''m'',[0,1],''var'',eye(2));',
   '' };
  slide(1).text={
   'Multivariate Density demo',
   'Density object can be created by entering their name followed by a list of parameters:',
   'gen=gaussdens(''m'',[0,1],''var'',eye(2));',
   'Here, gen is a gaussian density object with mean [0,1]'' and identity covariance matrix.',
   ''};

  %========== Slide 2 ==========

  slide(2).code={
   'cla;',
   'x = rand(gen,50);',
   'colplot(x);  %same as plot(x(:,1),x(:,2),''.'');' };
  slide(2).text={
   'Now it is possible to use a large variety of function.',
   'For example, we can generate 50 random samples from the previous density contained is the variable ''gen''. The samples are stored in the matrix x, each row corresponding to a sample.',
   'x = rand(gen,50);',
   'These samples are ploted on the figure.',
   'colplot(x);',
   'This command is the same as plot(x(:,1),x(:,2),''.'').'};

  %========== Slide 3 ==========

  slide(3).code={
   'show(gen,x);' };
  slide(3).text={
   'Now we can draw some isocontours this 2-dimensional density.',
   'We use the function ''show''.',
   'show(gen,x);'};

  %========== Slide 4 ==========

  slide(4).code={
   'est=learn(gaussdens,x);',
   'est',
   'show(est,''color'',[1,0,0]);' };
  slide(4).text={
   'The parameters of a density can easily be estimated by the function ''learn'' that return a density object with the estimated parameters.',
   'Here, ''est'' is a density object with the parameters estimated on the 50 previous points stored in the 2-columns matrix ''x''.',
   'look at the matlab command window to see the summary of the density parameters, and look at the above figure to se the contours of the estimated density in red.',
   'est=learn(gaussdens,x)',
   'show(est,''color'',[1,0,0]);',
   ''};

  %========== Slide 5 ==========

  slide(5).code={
   '' };
  slide(5).text={
   'here are the parameters that are returned if you type the object name in the command window:',
   '>> est',
   '',
   'gaussdens density:',
   'm''  = [0.118 1.18]',
   'var = [0.928 0.169',
   '       0.169 0.775]',
   ''};

  %========== Slide 6 ==========

  slide(6).code={
   'cla;',
   '',
   'show(balldens(''m'',[-2 1],''var'',1))',
   'text(-2.5,4.5,''balldens'');',
   '',
   'show(diagdens(''m'',[2 1],''var'',[2 .4]))',
   'text(1.5,4.5,''diagdens'');',
   '' };
  slide(6).text={
   'There exists  gaussian distributions with specific covariance matrices.',
   '',
   '"balldens" is a gaussian distribution with spherical covariance matrix',
   '"diagdens" is a gaussian distribution with diagonal covariance matrix',
   '"pcadens" is a spherical gaussian distribution with higher variance in the principal directions(not plotted here because in 2D, it is equivalent to an',
   'uncunstrained gaussian distribution).'};
end