% MLDEMO - Demo of the Maximum Likelihood estimation
%
% This demo show the parameter estimation of a mixture distribution with 2 gaussians
% with 2 different algorithm : 
% - the EM algorithm (Expectation-Maximization)
% - the Conjugate Gradient algorithm (Newton's method)
% 
% It shows that the two procedures give the same estimator.
%
% See also DENSITY/ML_LEARN (Conjugate Gradient), 
%          MIXTDENS/LEARN (Expectation-Maximization algorithm),
%          DEMOSSTATLEARN (Other demos of the Statistical Learning Toolbox).

%disp('This demo compares the EM algorithm and the Conjugate Gradient Algorithm')
%disp('to estimate the Maximum Likelihood parameters.')
help MLdemo

g1=gaussdens('m',[0 0]','var',eye(2));
g2=gaussdens('m',[3 3]','var',eye(2)*2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
disp('Distribution used to simulate the data:')
gen = mixtdens({g1,g2})
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

x=rand(gen,100);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
disp('Initial distribution (obtained by k-means):')
mxt0 = init(mixtdens(gaussdens,2,'commonparams','var'),x)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
disp('EM estimate:')
mxtEM=learn(mxt0,x)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
disp('Conjugate Gradient estimate:')
mxtCG=ml_learn(mxt0,x)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%





