% PARTIALCLDEMO - Classification of partially classified data
%   
% PARTIALCLDEMO This demo is used to illustrate the classification of data for 
% wich one class is not classified (partially classified data).
% In this example, we have 2-dimensional data arising from 2 unknown
% distributions: the positive data points and the negative data points.
% 
%   This demo show 4 graphs on a figure:
% 1) Training data that are unlabelled (we dont know wich data are positive and wich are negatives,
% The distribution that is used to simulate the positives is drawn, 
% but is considered to be unknown in the following.
% 2) Training data that are labelled as negatives
% The distribution that is used to simulate the negatives is drawn, 
% but is considered to be unknown in the following.
% 3) Result of the restricted K-means algorithm (KMEANSPARTIALCL)
% 4) Result of the EM algorithm applied on partially classified data 
% (MIXTDENS/LEARN_PARTIALCL)
%
% See also KMEANSPARTIALCL, MIXTDENS/LEARN_PARTIALCL



n=200;

posdens = {gaussdens('m',[0,0],'var',eye(2)*.5),...
                gaussdens('m',[4,4],'var',eye(2)*.5)};
negdens = {gaussdens('m',[4,0],'var',eye(2)*4),...
                gaussdens('m',[0,4],'var',eye(2)*4)};

pos = mixtdens(posdens);
neg = mixtdens(negdens);

gen = densitycl({mixtdens({pos,neg}),neg});

[x,cl]=rand(gen,n);    
partialcl = ones(n,4);
partialcl(find(cl==2),1:2) = 0;

est = learn_partialcl(mixtdens,x,[],partialcl,'niter',1);

%mxt = mixtdens({posdens{:},negdens{:}});        
estEM = learn_partialcl(est,x,[],partialcl,'niter',100,'epsi',1e-10,'display',1)
%mxt = learn(mxt,x,[],'niter',100,'epsi',1e-7,'display',0)

clf;
subplot(2,2,1)
show(pos);
colplot(x(find(cl==1),:))
title('Positve + negative (contours of the positive)')

subplot(2,2,2)
show(neg);
colplot(x(find(cl==2),:))
title('Negative')

subplot(2,2,3)
estcl = convert2classifier(est,[1 1 2 2]);
show(estcl,'SPLineWidth',4)
colplot(x,cl)
title('estimated model with partial kmeans');

subplot(2,2,4)
estclEM = convert2classifier(estEM,[1 1 2 2]);
show(estclEM,'SPLineWidth',4)
colplot(x,cl)
title('estimated model with EM');

