function [lval,grad] = NUMERICGRADIENT(func,x,check,varargin)
% NUMERICGRADIENT - Numerical approximation of the gradient
%
% grad = NUMERICGRADIENT(func,x)
% grad = NUMERICGRADIENT(func,x,0,P1,P2,...)
%
% func must be a string containing a function name accepting as arguments:
%   - a real vector of the same size as x
%   - P1, P2, ... are the following arguments passed to func
%
% Gradient checking
% -----------------
% If the function func as 2 output arguments where the second one is the gradient
%   computation,
%   [v,grad] = func(x,P1,...)
% then the validity of the gradient can be checked by the syntax
% NUMERICGRADIENT(func,x,1,P1,P2,...)
% If the gradients do not correspond, then they are displayed on the screen
%
% See also LOGVALUE, LOGVALUENUMERIC, STATLEARN

if nargin<3 | isempty(check)
    check=0;
end

x=x(:);
nargs = length(varargin);
params='';
for i=1:nargs
    params = [params ',varargin{' num2str(i) '}'];    
end
[lval,grad1] = eval([func '(x' params ');']);
dec = 1e-9;

if nargout>1 | check
    np = length(x);
    grad = zeros(np,1);
    for i=1:np     
        xcur=x;
        xcur(i)=xcur(i)+dec; 
        lvalcur = eval([func '(xcur' params ');']);
        grad(i) = (lvalcur - lval)/dec;
    end
end

if check
    falsegrad = find(abs(sum(abs(grad1-grad),1))>10*sqrt(dec));
    if ~isempty(falsegrad)
        disp(['evaluation of the parameters ' num2str(falsegrad) ' is false:']);
        [grad1 grad]
    else
        disp('gradient seems to be OK');
    end
end

if nargout==0
    clear lval grad
end