function c=svm(varargin)
%svm classifier object constructor
%
%c=svm creates a RBF Support Vector classifier with gamma=1 and C=0
% gamma is the smoothing parameter (variance of the gaussian kernel)
% C is the constraint violation parameter
%
% The parameters 'C' and 'gamma' can be specified (1 and 1 by default) 
% (type 'help RbfSVC' in the MATLAB shell for more informations)
%
% c=svm(...,'kernel_name','linear',...) creates a linear SVM classifier
% The parameters 'C' can be specified (1 by default). 
% (type 'help LinearSVC' in the MATLAB shell for more informations)
%
% c=svm(...,'kernel_name','poly',...) creates a polynomial SVM classifier
% The parameters 'degree','C','gamma' and 'coeff' can be specified. 
% (type 'help PolySVC' in the MATLAB shell for more informations)
% By defaults, these parameters are equal to 3, 1, 1 and 1
%
% intern variables setting:
% to set manually the parameters of the SVM classifier, the following
% values has to be properly set (See OSU_SVM documentation or type 
% 'help LinearSVC', 'help RbfSVC' or 'help OlySVC' for the
% meaning of these variables)
%    'alpha'
%    'sv'
%    'bias'
%    'parameters'
%    'nsv'
%    'labels'




alpha=[];
kernel_name = 'rbf';
sv = [];
bias = 0;
parameters = [];
nsv = [];
labels=[];

gamma=1;
degree=1;
coeff=1;
C=1;

%%% PARAMETERS MANAGEMENT
for i=1:2:length(varargin)
    if ~isstr(varargin{i}) | ~exist(varargin{i},'var')
        error(['Invalid parameter ' varargin{i}]);
    end
    eval([varargin{i} '= varargin{i+1};']);
end
%%%

s = struct(...
    'alpha',alpha,...
    'sv',alpha,...
    'bias',bias,...
    'parameters',parameters,...
    'nsv',nsv,...
    'labels',labels,...
    'degree',degree,...
    'C',C,...
    'gamma',gamma,...
    'coeff',coeff,...
    'kernel_name',kernel_name);

c = class(s,'svm',classifier);
