function err = eval_err(classifier,c,x,cl,losstype)
%EVAL_ERR Evaluates the error rate of a classifier
% err = eval_err(c,x,cl,losstype)
% returns the error rate of the classifier c on data x with true labels cl
%
%  losstype is the type of misclassification loss
%  losstype = '01'  by default, proportion of misclassified data
%  losstype = 'bayes' computes the bayes error rate ( for probabilistic classifiers)
%  losstype = 'negloglik' computes the negative conditional log-likelihood ( for probabilistic classifiers)
%  losstype = mat where mat is a KxK cost matrix. Use mat to weight the misclassifications.
%
% err = eval_err(classifier,carray,x,cl,losstype)
% multiple classifiers can be given in the cell array carray
%
% See also EVAL_ERRCV, EVAL_ERR_SIMUL

if ~isnumeric(c)
    if nargin<5
        losstype ='01';
    end
    if iscell(c)
        err = zeros(1,length(c));
        for i=1:length(c)
            err(i) = eval_err(c{i},x,cl,losstype);
        end
    else 
        err = eval_err(c,x,cl,losstype);
    end    
    return
else%switch the parameters
    if nargin<4
        cl ='01';
    end
    losstype=cl;
    cl=x;
    x=c;
    c = classifier;
    
    if iscell(cl)
        cellar = cl;
        cl = zeros(size(x,1),1);
        for k = 1:length(cellar)        
            cl(cellar{k}) = k;
        end
    end
    
    [n,d] = size(x);
    K = c.K;
    if isstr(losstype)
        switch(losstype)
            case '01'
                err = mean(classif(c,x)~=cl);
            case 'bayes'
                pc = proba_class(c,x);
                err = 1-mean(pc(sub2ind([n,K],1:n,cl')));
            case 'negloglik'
                pc = proba_class(c,x);
                err = -mean(log(pc(sub2ind([n,K],1:n,cl'))));
            otherwise
                warning('unknown loss type');
        end
    else        
        cl1=zeros(n,K);
        cl1(sub2ind([n,K],(1:n),cl')) = 1;
        cl2=zeros(n,K);
        cl2(sub2ind([n,K],(1:n),classif(c,x)')) = 1;
        cm = cl1'*cl2;
        mat = cm.*losstype;
        wellcl = diag(cm);
        err=sum(mat(:))/(sum(mat(:))+sum(wellcl));
    end
end