function [err,sd] = eval_err_simul(generator,c,n,ntest,losstype)
%EVAL_ERR_SIMUL Evaluate the error rate on simulated data
%
%   err = eval_err_simul(generator,c,ntrials) 
%   c is a classifier object
%   generator must be a densitycl object. It is used to simulate the data thanks to the rand function.
%   n can be either a scalar or a vector of 2 elements.
%       the first element gives the size of the generated samples for the training set.
%       the second (10000 by default) gives the size of the test sample.
%       The more it is the more the precision is
%   ntrials is the number of simulations to do (100 by default)
%   err contains all the vector all the evaluations of the arror rate
%
% [err,sd] = eval_err_simul(generator,c,n,ntrials)
%   err  is the expected error rate (mean of the previous vector err)
%   sd is the standard deviation of this error (std of the previous vector
%   err)
% [err,sd] = eval_err_simul(generator,carray,n,ntrials) applied the
% previous method on each classifeir in the cell array carray

if ~iscell(c) %if not cell array, switch arguments
    c={c};
end

if nargin<4
    ntest = 100;   
end

if nargin<5
    losstype = '01';   
end

if length(n)==1;
    n = [n,10000];
end

tab_err=zeros(ntest,length(c));

for test = 1:ntest
    if mod(test,50)==0
        disp([num2str(ceil(test*100/ntest)) '%']);
    end
    [x,cl] = rand(generator,n(1),1);
    c=learn(classifier,c,x,cl);
    tab_err(test,:) = bayeserror(generator,losstype,c,[n(2),10]);
%    disp([num2str(getparams(c{2})') '==>' num2str(tab_err(test,2))]);        
end

if nargout<=1
    err = tab_err;
else    
    err = median(tab_err);
    sd = std(tab_err);    
end
