function [err,sd,errtrain,sdtrain] = eval_errCV(c,x,cl,n_fold,ntests,losstype,dimred,temp)
%EVAL_ERRCV evaluates the cross-validated error rate
% [err,sd] = eval_errCV(c,x,cl,n_fold,ntests,losstype,dimred) 
% c is a classifier object 
% The function evaluates the error rate by Cross-Validation on the data x with classes cl
% err  is the expected error rate
% sd is the standard deviation of this error
%
% optional arguments
% n_fold  is the number of validation sets (2 by default: half sampling)
%           if nfold is negative, do not perform cross validation !
%           train the classifier on nappr = -nfold random data and then estimate the
%           error rate of the remaining data. do it ntests times
% ntests is the  number of tests (for each test, one CV error rate is computed)
% losstype is a string representing the type of cost function (see eval_err):
%       '01' (default) is the 0-1 error rate
%       'bayes' is the approximation on the test data of the bayes error rate
%       if losstype is a matrix, then it is used as a cost matrix.
% dimred specifies the pre-processing step of dimension reduction computed on 
%       test data AND training data (see reducedim function).
%
% [err,sd] = eval_errCV(classifier,carray,x,cl,n_fold,ntests,losstype,dimred) 
 %          the function evaluates the CV error rate on each classifiers in the cell array carray


if nargin<6
    temp=1;
end


if~iscell(x);
    if~iscell(c);
        c={c};
    end
    if nargin<4| isempty(n_fold)
        n_fold = 2;
    end
    if nargin<5
        ntests=1;
    end    
    if nargin<6
        losstype= '01';
    end    
    if nargin<7
        dimred= [];
    end    
else   % switch parameters 
    c = x;
    x = cl;
    cl = n_fold;
    if nargin<5
        n_fold = 2;
    else
        n_fold = ntests;
    end
    if nargin<6
        ntests = 1;
    else
        ntests = losstype;
    end
    if nargin<7
        losstype= '01';
    else
        losstype = dimred;
    end    
    if nargin<8
        dimred= [];
    else
        dimred= temp;
    end    
    
end

[n,d] = size(x);

if ~isempty(dimred)
    x0=x;
end

tab_err=[];
tab_err2=[];
if isempty(n_fold)
    n_fold=2;
end

if length(n_fold)<=1
    if n_fold>0
        for test = 1:ntests
            r = randperm(n);
            boxes = [floor((0:n_fold)*n/n_fold)+1];
            ncl = length(c);
            temp=zeros(n_fold,ncl);
            temp2=zeros(n_fold,ncl);
            
            for i=1:n_fold
                if(~mod(i+(test)*n_fold,5))
                    disp(['cross validation ' num2str(round((i+(test-1)*n_fold)/ntests/n_fold*100)) '%']);
                end                
                ind_test = r(boxes(i):boxes(i+1)-1);
                ind_appr = setdiff(1:n,ind_test);                
                if ~isempty(dimred)
                    x=reducedim(x0(ind_appr,:),cl(ind_appr),dimred,x0);
                end                
                c = learn(classifier,c,x(ind_appr,:),cl(ind_appr));
                temp(i,:) = eval_err(classifier,c,x(ind_test,:),cl(ind_test),losstype);
                if nargout>2
                    temp2(i,:) = eval_err(classifier,c,x(ind_appr,:),cl(ind_appr));
                end
            end
            tab_err = [tab_err;temp];
            tab_err2 = [tab_err2;temp2];
        end
    else % n_fold negative train/test estimation
        ntrain = min(-n_fold,floor(size(x,1)/2));
        K = max(cl);
        c0=c;
        for i=1:ntests
            disp(['Error rate estimation ' num2str(floor(i/ntests*100)) '%']);
            ind_appr=1;
            while ~isempty(setdiff(1:K,unique(cl(ind_appr)))) % if no member of each class do it again
                r = randperm(n);
                ind_appr = r(1:ntrain);
                ind_test = r(ntrain+1:end);
                
                if ~isempty(dimred)
                    x=reducedim(x0(ind_appr,:),cl(ind_appr),dimred,x0);
                end
                
                if ~isempty(setdiff(1:K,unique(cl(ind_appr))))
                    disp('missing class in training data');
                end
            end        
            c=learn(classifier,c0,x(ind_appr,:),cl(ind_appr));
            temp = eval_err(classifier,c,x(ind_test,:),cl(ind_test));
            tab_err = [tab_err;temp];
            if nargout>2
                temp2 = eval_err(classifier,c,x(ind_appr,:),cl(ind_appr));
                tab_err2 = [tab_err2;temp2];
            end                         
        end
    end
else % nfold contains the training indices
    ind_appr = n_fold;
    ind_test = setdiff(1:size(x,1),ind_appr);
    if ~isempty(dimred)
        x=reducedim(x0(ind_appr,:),cl(ind_appr),dimred,x0);
    end                
    c=learn(classifier,c,x(ind_appr,:),cl(ind_appr));
    temp = eval_err(classifier,c,x(ind_test,:),cl(ind_test));
    if nargout>2
        temp2 = eval_err(classifier,c,x(ind_appr,:),cl(ind_appr));
    end                         
    tab_err = [tab_err;temp];
    tab_err2 = [tab_err2;temp2];        
end

if nargout<=1|nargout==3
    err = tab_err;
else    
    err = median(tab_err,1);
    sd = std(tab_err);    
end

if nargout==3
    errtrain = tab_err2;
    sd=0;
end

if nargout>=3
    errtrain = median(tab_err2,1);
    sdtrain = std(tab_err2);
end
