function [h,proj_matrix] = show(c,varargin)
%SHOW Plot the classification boundaries of a classfier object
%
% SHOW(c,x,cl)
%       c : classifier object
%       x : x data (nxd) matrix
%       cl : classes of data (from 1 to K) vector of length n
%
% optional argument (by pairs arg_name/value):
%   - contour_densities (O/1)
%   - 
%
% See also DENSITY/SHOW, STATLEARN


contour_densities = 0; 
info = 0;
proj_matrix = [];
x=[];
cl=[];
lims=[];
show_points=1;
npoints=200;
to_print=0;
regions = 'flat';
margin = 0.2;
visible='on';

if length(varargin)>0 & iscell(varargin{1})
    varargin=varargin{1};
end

if length(varargin)>0 & ~isstr(varargin{1})
    x = varargin{1};
    varargin=varargin(2:end);
end
    
if length(varargin)>0 & isnumeric(varargin{1})
    cl = varargin{1};
    varargin=varargin(2:end);
    if length(varargin)>0 & iscell(varargin{1})
    varargin=varargin{1};
    end
end


remaining_varargin = {};
%%% PARAMETERS MANAGEMENT
if ~isempty(varargin) & iscell(varargin{1}),varargin=varargin{1};end
for i=1:2:length(varargin)
    if ~isstr(varargin{i}) | ~exist(varargin{i},'var')
        remaining_varargin=varargin(i:end);
        break
    end
    eval([varargin{i} '= varargin{i+1};']);
end
%%%


d=getdim(c);

if isempty(d)
    warning('The dimension of the classifier is null. This may cause errors in the following.');
end

if isempty(x)
    [x,cl]=rand(c,npoints);    
    show_points=0;    
elseif isempty(cl)
    cl = classif(c,x);
end

n = size(x,1);
K = getnbcl(c);
ncoclass=floor(256/K);

if strcmp(class(c),'densitycl')
    contour_densities = 1;
end

if d==1
warning('dimension 1 not implemented');    
    return
end

if isempty(d) | d==2
    proj_matrix = eye(2);
    xred=x;
else
    if isempty(proj_matrix)
        [xred,proj_matrix] = reducedim(x,cl,2);
        if isempty(proj_matrix)
            proj_matrix = [eye(2);zeros(d-2,2)];
        end
    end
    if ~isempty(x)
        xred = x*proj_matrix;
    end
end    

if ~isempty(x) & isempty(lims) %if there are data to plot
    lims = [min(xred);max(xred)];
else
    if isempty(lims)
        lims = [-10 -10;10 10];    
    end
end


if isempty(lims) | length(lims(:))<4
    lims = lims+margin*[-1;1]*diff(lims);
else
    if d>1
        lims=reshape(lims(1:4),[2,2]);
    end
end

nx = 50;
ny = 50;
xt = (0:nx)/nx*(lims(2,1)-lims(1,1))+lims(1,1);
yt = (0:ny)/ny*(lims(2,2)-lims(1,2))+lims(1,2);

[xtemp,ytemp] = meshgrid(xt,yt);
xp = [xtemp(:) ytemp(:)];
%V = eye(2);%projection vector to most informative plane
V = proj_matrix;
xpp = (V*xp')';
%find the probas for points xpp to belong to classes
prob = proba_class(c,xpp);
prob=prob./(sum(prob,2)*ones(1,K));

switch regions
    case 'image'
        thecmap=zeros(K*ncoclass,3);
        im = zeros(size(prob,1),1);
        for k=1:c.K
            os = 1+(k-1)*ncoclass;
            thecmap(os:os+ncoclass-1,:) = (1:ncoclass)'/ncoclass*cmap(k);
            z = prob(:,k)-(max(prob(:,[1:k-1 k+1:end]),[],2)-eps);
            ind = find(z>0);
            im(ind)=floor(z(ind)*ncoclass)+os;
        end
        im=reshape(im,[nx+1,ny+1]);
        %im2=ind2rgb(im,thecmap);
        %imshow(im2);
        colormap(thecmap);
        image(xt,yt,im);
        
    case 'flat'
        hold on
        for k=1:c.K
            z = prob(:,k)-(max(prob(:,[1:k-1 k+1:end]),[],2)+eps);
            z=reshape(z,[nx+1,ny+1]);
            [C,h,cf] = contourf(xtemp,ytemp,z,[0 0]);
            set(h,'FaceColor',1-(1-cmap(k))*(.25-.2*to_print),'FaceAlpha',1,'LineWidth',3,'Visible',visible)
        end
    case 'none'
        
    case 'smooth'
        warning('smooth not implemented yet')
end

%show density contours if option is selected
if contour_densities
    hold on
    show_densities(c,x,remaining_varargin);
end


if ~isempty(x) & show_points %if there are not random data
    %missclassified points
    bad_cl=find(cl-classif(c,x)~=0);
        
    axis_pos = get(gca,'Position');
    
    
    %show points with colors corresponding to their true class 
    % and stress missclassified points
    xr = x*proj_matrix;
    colplot(xr,cl,'MarkerSize',12);
    line(xr(bad_cl,1),xr(bad_cl,2),'LineStyle','none','Marker','o','Color',[.5,.5,.5],'MarkerSize',6)
    set(gca,'XLim',lims(:,1));
    set(gca,'YLim',lims(:,2));
    
    if info & n>0;
        err = length(bad_cl)/n;
        label = ['training error = ' num2str(err)];
        tx = get(gca,'XLim');tx = tx*[.95;.05];
        ty = get(gca,'YLim');ty = ty*[.05;.95];
        text(tx,ty,label);
    end
    
end



axis off
%xlabel('x1');
%ylabel('x2'); 



hold off


if nargout<1 
    clear proj_matrix h
    %proj_ma is used by showclassifiers
end