function err = bayeserror(c,losstype,models,n)
%BAYESERROR Compute the classification error rate of a joint density
%
% err = bayeserror(c)
% compute the 01 error of the densitycl classifier assuming the true
% density is the one define by the model
%
% err = bayeserror(c,losstype) can set the type of loss function ('01' or
% 'bayes') see eval_err function
% 
% err = bayeserror(c,losstype,model) c defines the true density and model
% is the classifier object whose performances are mesured
%
% err = bayeserror(c,losstype,models) models can be a cell array of
% classifier ojects
%
% err = bayeserror(c,losstype,models,[n1,n2]) 
% or err = bayeserror(c,losstype,models,[n1,n2]) 
% sets the numbers of trials used to integrate the error rate
% (total of n1*n2 trials)
%
% See also EVAL_ERR

if nargin<2
    losstype='01';
end

if nargin<3| isempty(models)
    models={c};
end

if nargin<4
    n=[5000,10];
end

if ~iscell(models)
    models={models};
end


nmodels = length(models);

err=zeros(n(2),nmodels);
for i=1:n(2)
        [x,cl] = rand(c,n(1));
    for m=1:nmodels
        err(i,m) = eval_err(models{m},x,cl,losstype);
    end
end
err = median(err);