function c = learn(c,x,cl,varargin)
%LEARN Finds the parameters of a classifier based on density estimation
%
% c = learn(c,x,cl,w)
% finds the parameters of an densitycl classifier
% This function is VIRTUAL, that is to say cannot be applied to densitycl object,
% but to inhereted objects of this class that have the learn_density method
% c : densitycl object
% x : data of size nxd where n is the number of data and d their dimension
% cl : indexes of the groups of the data (supervised learning) between 1 and K or 0 and K-1
% can be a n*1 vector or a K*1 cell array with vector of indices inside
% w(optional) : weights of the data (default ones(n,1)/n)
%
% See also DENSITYCL, DENSITY/LEARN, DENSITY

[n,d] = size(x);
w=ones(n,1);

if n>5000 
    display='iter';
else
    display='none';
end

if ~isempty(varargin) &iscell(varargin{1})
    varargin = varargin{1};
end

nargs= length(varargin);

for i=1:2:nargs
    switch(varargin{i})
        case 'display',  display = varargin{i+1};
        case 'w',  w = varargin{i+1};
        otherwise, 
            error(['invalid argument name ' varargin{i}]);       
    end
end



I = components2cell(cl);
K = length(I); %number of classes
    
if isempty(c.p) | length(c.p)~=K | ~c.knownp
    c.p = ones(1,K);
    for k = 1:K
        c.p(k) = sum(w(I{k}));
    end
    c.p=c.p./sum(c.p);
end

if length(c.densities)==1
    if ~iscell(c.densities)
        dens = c.densities;
    else
        dens = c.densities{1};
    end
    c.densities = cell(1,K);
    for k=1:K
        c.densities{k} = dens;
    end
elseif length(c.densities)~=K
    K=K
    length_densities = length(c.densities)
    error('The number of classes in the data do dot match the classifier definition');
end


%MAIN LOOP

for k = 1:K
    c.densities{k} = learn(c.densities{k}, x(I{k},:), w(I{k}));
end    

%END OF MAIN LOOP

if ~isempty(c.commonparams) %dependents parameters
    c.densities = mixcommonparams(c.densities{1},c.densities(2:end),c.commonparams,c.p);
end
c.p = c.p/sum(c.p);
c = setnbcl(c,K);
c = setdim(c,d);

return 

if c.lambda~=0
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %                   CONJUGATE GRADIENT DESCENT
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    opt = optimset('GradObj','on','TolX',1e-6,'MaxIter',50,'Display',display);
    %    opt = optimset('GradObj','on','Display','iter');
    %opt = optimset('Display','iter','MaxIter',300);
    theta0 = getparams(c);
    theta = fminunc('objectivefunction',theta0,opt,c,x,cl,w);
    c = setparams(c,theta);
    
end
