function [ll,grad] = loglik(c,x,cl)
% LOGLIK - Log-likelihood of the classifier parameters
%
% ll = loglik(c,x,cl) is the joint log-likelihood 
% 
% [ll,grad] = loglik(c,x) is the marginal log-likelihood
%
% See also LOGVALUE

[n,d] = size(x);

K = getnbcl(c.classifier);

if nargin<3 | isempty(cl)
    lprob = zeros(n,K);
    for k=1:K
        lprob(:,k) = log(c.p(k)+1e-320) + logvalue(c.densities{k},x);
    end               
    ll= sum(log(sum(exp(lprob),2)+1e-320));
else
    I = components2cell(cl);
    ll=0;
    for k=1:K
        lprob = log(c.p(k)+1e-320) + logvalue(c.densities{k},x(I{k},:));
        ll = ll + sum(lprob,1);
    end        
end

return

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%












%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if nargout==1
    else
        prob = zeros(n,K);
        for k=1:K;
            prob(:,k) = c.p(k)*value(c.densities{k},x)+1e-320;
        end
        logpgc = log(prob(sub2ind([n,K],(1:n)',cl)));%log of the probabilities of good classification
        logsp = log(sum(prob,2)); %log of the sum of the probabilities
        ll = sum(logpgc) - c.lambda*sum(logsp);
    end

 %nargout>=2  gradient required
    if isempty(c.commonparams)
        prob = zeros(n,K);
        logdens = zeros(n,K);        
        np = length(getparams(c.densities{1}));
        gradlogdens = zeros(n,np,K);
        for k=1:K;
            [logdens(:,k),gradlogdens(:,:,k)] = logvalue(c.densities{k},x);
        end
        prob = exp(logdens+ones(n,1)*log(c.p))+1e-320;
        ind = sub2ind([n,K],(1:n)',cl);
        pgc = prob(ind);%probability of good classification
        sp = sum(prob,2); %sum of the probabilities
        ll = sum(log(pgc)) - c.lambda*sum(log(sp));    
        tau =  c.lambda*prob./(sp*ones(1,K));
        tau(ind) = tau(ind)-1;
        grad = -sum(reshape(repmat(reshape(tau,[n,1,K]),1,np).*gradlogdens,[n,np*K]))';
    else
        prob = zeros(n,K);
        logdens = zeros(n,K);        
        gr = cell(1,K);
        for k=1:K;
            [logdens(:,k),gr{k}] = logvalue(c.densities{k},x);
        end

        prob = exp(logdens+ones(n,1)*log(c.p))+1e-320;
        ind = sub2ind([n,K],(1:n)',cl);
        pgc = prob(ind);%probability of good classification
        sp = sum(prob,2); %sum of the probabilities
        ll = sum(log(pgc)) - c.lambda*sum(log(sp));    
        tau =  c.lambda*prob./(sp*ones(1,K));
        tau(ind) = tau(ind)-1;
        
        np = n_params(c);
        gradlogdens = zeros(n,np);
        ncommon = n_params(c.densities{1},c.commonparams);
        pos = 1;
        for k=1:K;
            npdenstot = size(gr{k},2);
            npdens = npdenstot-ncommon;
            ind = [pos:pos+npdens-1,np-ncommon+1:np];
            gradlogdens(:,ind) = gradlogdens(:,ind) + gr{k}.*(tau(:,k)*ones(1,npdenstot));
            pos = pos+npdens;
        end
        grad = -sum(gradlogdens)';
    end
    