function [lval,grad] = loglikgradnumeric(c,x,y,check)
%LOGLIKGRADNUMERIC gives numerical approximation of the parameters gradient on the given samples
%
% [lval,grad] = loglikgradnumeric(c,x,cl)
%
% [lval,grad] = loglikgradnumeric(c,x,cl,1) check the validity of the loglik
% function to estimate the gradient

if nargin<4
    check=0;
end

[n,d] = size(x);
dec = 1e-7;


lval = loglik(c,x,y);
p0 = getparams(c);
np = length(p0);    
grad = zeros(np,1);
for i=1:np     
    par = p0;
    par(i)=par(i)+dec; 
    c=setparams(c,par);
    grad(i,:) = (loglik(c,x,y) - lval)/dec;
end
end

if check
    [lval1,grad1] = loglik(c,x,y);    
    falsegrad = find(abs((grad1-grad))'>1e-3);
    if ~isempty(falsegrad)
        disp(['evaluation of the parameters ' num2str(falsegrad) ' is false']);
    else
        disp('gradient seems to be OK');
    end
end

if nargout==0
    clear lval grad
end