function prob = proba_class(c,x,lambda)
%PROBA_CLASS Probabilities of the classes given the covariates
%
%   prob = proba_class(c,x,[lambda]) 
%   Gives the probabilities in the vector prob of size nxK of the different classes.
%   K in the inner attribute of the base object classifier that gives the number of classes
%   x must be a matrix where each of its n rows corresponds to a data
%   lambda is the power of the normalization constant. If lambda = 1, the sum of the probas makes one.
%   lamdba = 1 by default

[n,d] = size(x);

K = length(c.densities);
prob = zeros(n,K);


for k=1:K
    prob(:,k) = c.p(k)*value(c.densities{k},x);
end

prob=prob./(1e-320 + sum(prob,2)*ones(1,K));
