function c=set(c,varargin)
% SET Set the parameters of a densitycl distribution
% 
% c= SET(c,...,'parname',V,...)
% parameters are set by pairs parameters name/parameter value
% possibles paramters names
%
% c= SET(c,...,'prop',p,...) set the proportions of the classes to p
%
% c= SET(c,...,'commonparams' ,V,...) set the proportions of the clases to p
% force the parameter specified as a string in V to be the same for all the
% density components.
%
% IMPORTANT : AFTER THESE densitycl PARAMETERS
% The parameter of the components can be set by simply specifying the name
% that is passed to the method SET of the component.
% for example,
% c= set(c,'commonparams','var','m',[0,2])
% return densitycl of 2 densities (already specified in c) with means 0 and 2
%
%
% See also DENSITYCL/GET, CLASSIFIER/SET, MIXTDENS/SET
%   CLASSIFIER, CLUSTERING, MIXTDENS, UNSUPERVISED, STATLEARN

if isempty(varargin)
    return
end

commonparams = [];
K=length(c.p);
densities=c.densities;
p=[];
knownp=0;

dens_args=[];
%%% PARAMETERS MANAGEMENT
if ~isempty(varargin) & iscell(varargin{1}),varargin=varargin{1};end
for i=1:2:length(varargin)
    if ~isstr(varargin{i}) | ~exist(varargin{i},'var')
        dens_args=varargin(i:end);
        break
    else
        eval([varargin{i} '= varargin{i+1};']);
    end
end
%%%
c.knownp = knownp;


if ~isempty(p)
    c.p=p(:)';
    K=length(c.p);
    c = setnbcl(c,K);        
end

if ~isempty(c.densities)
    if ~iscell(c.densities)
        c.densities={c.densities};
    end
    c = setdim(c,getdim(c.densities{1}));
    if length(c.densities)==1
        c.densities=c.densities(ones(1,K));
    end
end


K = length(c.densities);
c = setnbcl(c,K);


if ~isempty(dens_args)
    if iscell(densities)        
        densities=densities{1};
    end
    K = size(dens_args{2});K = K(end);    
    args = dens_args;
    c.densities = cell(1,K);
    for k=1:K
        for a=2:2:length(args)
            nd=sum(size(dens_args{a})>1);
            if nd==1
                args{a} = dens_args{a}(k);
            elseif nd==2
                args{a} = dens_args{a}(:,k);
            else
                args{a} = dens_args{a}(:,:,k);
            end
        end
        c.densities{k}=set(densities,args);
    end
    c = setdim(c,getdim(c.densities{1}));
    c = setnbcl(c,K);        
end


if ~isempty(commonparams)
    c.commonparams = commonparams;
    if length(c.p)>1 & getdim(c.densities{1})>0
        c.densities=mixcommonparams(c.densities{1},c.densities(2:end),commonparams,c.p)
    end
end


if isempty(c.p)        
    c.p = [ones(1,K)]/K;    
elseif length(c.p)~=length(c.densities) & length(c.densities)>1
     error('The number of proportions and the number of classes are different.')
end
