function c = learn(c,x,cl,w,varargin)
%LEARN learn parameters of the mixtdenscl classifier
%
%c = learn(c,x,cl,w,J,niter)
%	Find the parameters of an mixtdenscl classifier
%	c : densitycl object
%	x : data of size nxd where n is the number of data and d their dimension
%  cl : indexes of the groups of the data (supervised learning) between 1 and K or 0 and K-1
%			can be a n*1 vector or a K*1 cell array with vector of indices inside
%  w(optional) : weights of the data (default ones(n,1)/n)
%

[n,d] = size(x);

niter = 30;

%%% PARAMETERS MANAGEMENT
for i=1:2:length(varargin)
    if ~isstr(varargin{i}) | ~exist(varargin{i},'var')
        error(['Invalid parameter ' varargin{i}]);
    end
    eval([varargin{i} '= varargin{i+1};']);
end
%%%


if nargin<4 | isempty(w);
   w = ones(n,1); %equal weights
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

celldata = lbl2cell(x,cl);
K = length(celldata);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

om=cell(1,K);
dens = getdensities(c.densitycl);
basedens = getdensities(dens{1});
basedens = setdim(basedens{1},d);


R=zeros(1,K);
num=zeros(1,K);
prop=cell(1,K);

%initialization
for k=1:K
    R(k) = getnbcl(dens{k});
    num(k) = size(celldata{k},1);
    om{k}=zeros(num(k),R(k));
    [m,affect] = kmeanslight(celldata{k},R(k));
    om{k}(sub2ind(size(om{k}),1:num(k),affect))=1;
    om0{k} = om{k};    
    prop{k} = ones(1,R(k))/R(k);
end
csR=[0,cumsum(R)];
sumR = csR(end);
densities = cell(1,sumR);
prior = num/sum(num);
c.densitycl = setprop(c.densitycl,prior);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%EM-algorithm

%---------------------------------------------------------------------------------------------------------------------------------------------

ll=[0];
restart = 3;
maxrestart = 5;

mincounts = 1+n_params(basedens);
 if mincounts*sumR>n
     warning(['' num2str(n) ' data are not enough to learn a mixture of ' num2str(sumR) ' densities with ' num2str(n_params(basedens)) ' parameters']);
     niter = 2;
 end

p=ones(1,sumR);
counts=cell(1,K);
ll=-ones(1,K)*1e99;
lltot=[];
for it = 2:niter+1 %beginning of the loop      
    for k=1:K
        counts{k} = sum(om{k});
        prop{k} = max(.001,counts{k}/n);
        prop{k} = prop{k}/sum(prop{k});
       
        for r=1:R(k)
            if counts{k}<mincounts & restart <5 %if few data in a cluster                
                densities{csR(k)+r} = learn(basedens,celldata{k},1./max(om0{k},[],2));
                restart = restart+5;                
            else
                densities{csR(k)+r} = learn(basedens,celldata{k},om{k}(:,r));
            end                
        end
        p(csR(k)+1:csR(k+1)) = prop{k}*prior(k);
    end
    
    if ~isempty(c.commonparams)  %dependents parameters       
        densities = mixcommonparams(densities{1},densities(2:end),c.commonparams,p);
    end

    for k=1:K
        for r=1:R(k);
            om0{k}(:,r) = prop{k}(r)*value(densities{csR(k)+r},celldata{k})+eps;
        end
        ll(k) = sum(log(sum(om0{k}')));
        %normalization of the rows to obtain probabilities of belonging to each class for every data
        om{k} = om0{k}./repmat(sum(om0{k},2),1,R(k)); %normalize the lines
    end
    %log-likelihood  
    lltot(it)=sum(ll);
    conv = (restart<0 & abs(lltot(it)-lltot(it-1))<1e-4*n | restart>maxrestart);

    if conv % stop test : 
        break      
    end
%    disp([num2str(it) ' ll = ' num2str(lltot(it))]); %display the iterations of the EM algorithm
    restart=restart-1;
end 

% if display
%         fprintf('d=%d,n=%d,K=%d==>np=%d\n',d,n,K,n_params(c));
%     if restart>maxrestart
%         disp(['EM cannot convergence due to infinite maximum likelihood (' num2str(K) ' groups)']);        
%     elseif conv 
%         disp(['EM convergence in ' num2str(it) ' iterations (' num2str(K) ' groups)']);
%     else
%         disp(['EM stopped before convergence in ' num2str(niter) ' iterations (' num2str(K) ' groups)']);
%     end
% end

for k=1:K
    dens{k} = mixtdens(densities(csR(k)+1:csR(k+1)),R(k),'p',prop{k});
end

c.densitycl=setdensities(c.densitycl,dens);
