function c = biclearn(c,x,cl,w)
%c = learn(c,x,cl,w)
%
%	Find the parameters of an MixtDensCl classifier
%	c : densitycl object
%	x : data of size nxd where n is the number of data and d their dimension
%  cl : indexes of the groups of the data (supervised learning) between 1 and K or 0 and K-1
%			can be a n*1 vector or a K*1 cell array with vector of indices inside
%  w(optional) : weights of the data (default ones(n,1)/n)


[n,d] = size(x);

I = components2cell(c,cl);
K = length(I); %number of classes


if nargin<4
   w = ones(n,1); %equal weights
end

c.R = 2:K+1;
c.densitycl.K = K;
p = ones(1,K); 
dens = cell(1,K);

for k = 1:K
    p(k) = sum(w(I{k}));
    c.R(k) = 1;
    newdens = eval(['MixtDens(''' c.densitycl.dens_class_name ''',c.R(k))']);   
    newdens = learn(newdens, x(I{k},:), w(I{k}));
    newbic = bic_score(newdens,x(I{k},:),w(I{k}));
    oldbic = newbic;
    
    while newbic<=oldbic
        olddens = newdens;   
        oldbic=newbic;        
        c.R(k) = c.R(k)+1;
        newdens = eval(['MixtDens(''' c.densitycl.dens_class_name ''',c.R(k))']);   
        newdens = learn(newdens, x(I{k},:), w(I{k}));
        newbic = bic_score(newdens,x(I{k},:),w(I{k}));
    end
    dens{k} = olddens;
    disp(['R(' num2str(k) ') = ' num2str(c.R(k))]);
end

c.densitycl.densities = dens;
c.densitycl.p = p/sum(p);
