function c=classifierplot(c,x,cl,names,varargin)
% CLASSIFIERPLOT - plot a cell array of classifiers applied on data
% c=classifierplot(c,x,cl,names,varargin)
%   c: cell array of classifier
%   x: input data (regressors)
%   y: labels data
%   names: titles of the plots (cell array)
%   varargin: list of pairs of arguments
%
% See also STATLEARN
if ~iscell(c)
    c={c};
end

L = length(c);

if ~isempty(x)
    for i=1:L
        c{i}=learn(c{i},x,cl);
    end
else
    [x,cl]=rand(c{1},1000);
end

if nargin<4 | isempty(names)
    names = cell(1,L);
end        

CV = 0;

nargs = length(varargin);
if nargs>0
    for i=1:2:nargs
        switch(varargin{i})
            case 'CV'
                CV = varargin{i+1};
            otherwise
                warning([varargin{i} ' is an invalid argument']);
        end
    end
end

clf;
nli  = ceil(sqrt(L));nco = ceil(L/nli);
[xr2D,proj2D] = reducedim(x,cl,2);    

for i=1:L
    if isempty(names{i})
        names{i}=class(c{i});
    end
    subplot(nli,nco,i);
    if CV
        [errtest,errteststd,errtrain,errtrainstd] = eval_errVC(c{i},x,cl,CV);         
        show(c{i},x,cl,'title',names{i},'proj_matrix',proj2D,'label',sprintf('Training error : %1.4f\n%d-fold CV : %1.4f',errtrain,CV,errtest));
    else
        show(c{i},x,cl,'title',names{i},'proj_matrix',proj2D);
    end
    drawnow
end
