function [lval,grad,H] = DERLOGLIKNUMERIC(c,x,w)
% DERLOGLIKNUMERIC - Numerical approximation of the gradient and hessian of the log-density
%
% [lval,grad] = DERLOGLIKNUMERIC(c,x) return logvalue of the density at points
%   x
% [lval,grad,hessian] = DERLOGLIKNUMERIC(c,x)
%
% See also DENSITY, LOGVALUE
%   UNSUPERVISED, STATLEARN

p0 = getparams(c);
np = length(p0);
[n,d] = size(x);

if nargin<3
    w=ones(n,1);
end

lval = logvalue(c,x)'*w;

if nargout==2
    dec = 1e-8; %gives empirically smallest errors on "reasonable" distributions
                %use normalized data if it goes wrong
    grad = zeros(np,1);
    for i=1:np
        par = p0;
        par(i) = par(i) + dec;
        c = setparams(c,par);
        grad(i) = (logvalue(c,x)'*w - lval)/dec;
    end
    
elseif nargout>2 %hessian and gradient computation
    dec = 1e-4;
    A = zeros(np,np);
    B = zeros(np,1);
    for i=1:np
        par = p0;
        par(i) = par(i) + dec;
        c = setparams(c,par);
        B(i) = logvalue(c,x)'*w;
        for j=1:np
            par = p0;
            par(i) = par(i) + dec;
            par(j) = par(j) + dec;            
            c = setparams(c,par);
            A(i,j) = logvalue(c,x)'*w;
        end
    end    
    grad = (diag(A)-lval)/(2*dec);
    H = zeros(np,np);
    Hdiag = 2/dec*((B-lval)/dec-grad); 
    M = ones(np,1)*(grad + dec/2*Hdiag)';
    H = ((A-lval)/dec - M - M')/dec;
end

