function ll = loglik(c,x,w)
%LOGLIK Log-Likelihood of a density parameters applied on data
%
% ll = LOGLIK(c,x) computes the log-likelihood of the parameters of the 
% parametric distribution c applied on nxd data matrix x
% The classic formula 
%       LL = sum_i=1^n log(value(c,x))
% is used, where value is the function that return the density values of the 
% n data points in x
%
% The parameters are included in the density c. To set or get them, use 
% c=SETPARAMS(c) or GETPARAMS(c)
%
% ll = LOGLIK(c,x,w) is the weighted version of the lielihood where w is a nx1 vector of weights
%
% See also DENSITY/VALUE, CLASSIFIER/LOGLIK, DENSITY/SETPARAMS, DENSITY/GETPARAMS.

if nargin<3
    w = ones(size(x,1),1);
end

ll = sum(logvalue(c,x).*w);
