function [lval,grad] = logvaluenumeric(c,x,check)
%LOGVALUENUMERIC gives numerical approximation of the log-density and parameters gradient of samples
%
% [lval,grad] = logvaluenumeric(c,x)
%
% logvaluenumeric(c,x,1) check the validity of the logvalue
% function to estimate the gradient
%
% See also LOGVALUE, STATLEARN

if nargin<3
    check=0;
end

[n,d] = size(x);
dec = 1e-9;

lval = log(value(c,x));
if nargout>1 | check
    p0 = getparams(c);
    np = length(p0);
    grad = zeros(n,np);
    for i=1:np     
        par = p0;
        par(i)=par(i)+dec; 
        c=setparams(c,par);
        grad(:,i) = (log(value(c,x)) - lval)/dec;
    end
end

if check
    [lval1,grad1] = logvalue(c,x);
    if abs(lval1-lval)>10*sqrt(eps)
        disp('evaluation of the logarithm is false');
    else
        disp('log-density seems to be OK');
    end
    
    falsegrad = find(abs(sum(abs(grad1-grad),1))>n*10*sqrt(dec));
    if ~isempty(falsegrad)
        disp(['evaluation of the parameters ' num2str(falsegrad) ' is false']);
    else
        disp('gradient seems to be OK');
    end
end

if nargout==0
    clear lval grad
end