function rr=rand(c,n,varargin)
% RAND - Random points generated according to the underlying density
%
% R = rand(c,n) returns a random points matrix R with n rows
%
% c : density Object
% n : number of random samples
% r : random matrix of size n x d
%
% This function uses the accept-reject algorithm based on a multivariate gaussian density
% (See abject GAUSSDENS)  with mean and variances of the function GAUSSDENS/STATS of the simulated density
%
% arguments by pairs:
%
% r=rand(c,n,'gen',nit) defines the proposal density (which is the gaussdens distribution by default)
% r=rand(c,n,'nit',nit) maximal number of accept-reject iterations
% r=rand(c,n,'display',1) plots the number of iterations needed by the accept-reject algorithm
% r=rand(c,n,'display',2) plots the number of iterations and the acceptance rate at the last iteration
%
% use Rejection sampling with multivariate gaussian proposal
% to randomize according to the true density.
%
% See also GAUSSDENS, GAUSSDENS/STATS
%   RAND, DENSITYCL/RAND, STATLEARN

display = 0;
nit = 10;
gen = [];

%%% PARAMETERS MANAGEMENT
if ~isempty(varargin) & iscell(varargin{1}),varargin=varargin{1};end
for i=1:2:length(varargin)
    if ~isstr(varargin{i}) | ~exist(varargin{i},'var')
        error(['Invalid parameter ' varargin{i}]);
    end
    eval([varargin{i} '= varargin{i+1};']);
end
%%%

if isempty(gen)
    try
        [m,v]= stats(c);
        if length(m)~=size(v,1)
            error
        end
    catch
        error(['The density object of class ' class(c) ' may not have a valid function STAT']);
    end
    gen = gaussdens('m',m,'var',v);
end

d = getdim(c);
nonselected = ones(1,n);

rr = zeros(n,d);

pos = 0;
it=0;

while pos<n
    nremain = n-pos;
    u = rand(gen,nremain);
    ratio = exp(logvalue(c,u)-logvalue(gen,u));
    sel = find(rand(nremain,1)<ratio);    
    newpos = pos +length(sel);
    rr(pos+1:newpos,:) = u(sel,:);
    pos=newpos;
    it=it+1;
    if it>nit
        break
    end
 end
 if display>=1
     fprintf('Number of iterations : %d',it);
     if display>=2
         fprintf('probabilities of acceptance:');                
         disp(ratio)
     end 
 end 
 