function h=show(c,varargin)
%SHOW Plot a probability distribution or a linear projection of it
%
% This function calls different methods, depending on the dimension of the data 
% or the dimension specified by the user.
%
% SHOW(c) plot the distribution c
% - calls DENSITY/SHOW1 if c is 1-dimensional (i.e. getdim(c)==1)
% - calls DENSITY/SHOW2 if c is 2-dimensional (i.e. getdim(c)==2)
% - calls DENSITY/SHOW3 if c is 3-dimensional (i.e. getdim(c)==3)
% - calls DENSITY/SHOW2 if c is n-dimensional, n>3 (i.e. getdim(c)>3)
%
% h=SHOW(c) returns a set of handles depending on the plotting function
%
% h=SHOW(c,'dim',d) plots a n-dimensional distribution in d dimensions
% n must be greater than d
% if d is smaller than 3, the projection is computed by using a specific projective 
% distribution (see the object SLICEDENS)
%
%See also SHOW CLASSIFIER/SHOW DENSITY/SHOW DENSITY/SHOW3 DENSITY/SHOW1, SLICEDENS,
%   STATLEARN, UNSUPERVISED

dim = min(c.d,2);
if c.d==3
    dim=3;
end

if nargin>1 & isnumeric(varargin{1})
    x=varargin{1};
    varargin=varargin(2:end);
else
    x=[];
end
if length(varargin)>=1 & iscell(varargin{1})
    varargin=varargin{1};
end

if length(varargin)>=1 & isstr(varargin{1}) & strcmp(varargin{1},'dim')
    dim = varargin{2};
    varargin=varargin(3:end);
end

%%% PARAMETERS MANAGEMENT
if ~isempty(varargin) & iscell(varargin{1}),varargin=varargin{1};end
for i=1:2:length(varargin)
    if ~isstr(varargin{i}) | ~exist(varargin{i},'var')
          vararginrem=varargin(i:end);break;
    end
    eval([varargin{i} '= varargin{i+1};']);
end
%%%


if dim<c.d
    [m,S]=stats(c);
    opts.disp=0;
    [V,l]=eigs(S,dim,'LM',opts);
    c = slicedens(c,'offset',m,'proj_mat',V);        
    if ~isempty(x)
        x = x*V;
    end
end

if ~isempty(x)
    varargin={'show_points',1,varargin{:}};
end

switch dim
    case 1
        h = show1(c,x,varargin);
    case 2
        h = show2(c,x,varargin);
    case 3
        h = show3(c,{'x',x,varargin{:}});
    otherwise
        error('Invalid dimension for plotting');
end

if nargout<1
    clear h
end
