function v=value_at_quantile(c,prop,x)
%VALUE_AT_QUANTILE Density value of the quantiles isocontours
%
% A quantile isocontour is a isocontour of the density that contains a 
% given proportion of the density. This enables the function 'show' to 
% draw an isocontour that always contains 80% or 95% of the total mass.
% See the option 'quantiles' of DENSITY/SHOW for changing these values 
% or adding more contours.
% 
% v=value_at_quantile(c,q)
% return the value of the density that contains a proportion q in (0,1) 
% of the total distribution mass. This value is approximated by simulating 
% data from the density and estimating sorted density value having rank ceil(n*q).
% Multiple quantiles are given in a vector q.
%
% v=value_at_quantile(c,q,x)
% 

if nargin<3 | isempty(x)
    %number of simulated points
    n=20+ceil(1/(1.001-max(prop)));
    %random sample
    x=rand(c,n);
else
    n=size(x,1);
end

%sorted 
val=sort(value(c,x));
v=val(ceil((1-prop)*n));
