function c=diagdens(varargin)
%DIAGDENS Create a gaussian distribution with diagonal covariance matrix
%
% c=diagdens
% returns a empty diagonal gaussian density object. Such empty objects can be used
% functions like 'learn(diagdens,x)' that directly affects parameters to the
% density.
% 
% c=diagdens('m',M) 
% returns a diagonal gaussian with mean M and identity covariance matrix.
%
% c=diagdens('m',M,'var',S)
% returns a diagonal gaussian with mean M and covariance matrix S.
% Only the diagonal elements of S are used.
%
% c=diagdens('m',M,'var',v)
% v is a vector containing the diagonal elements
% of the covariance matrix.  
%
% c=diagdens('m',M,'sqrtdiago',v)
% v is a vector containing the square roots of the diagonal elements
% of the covariance matrix.  
%
% Example:
%  dens = diagdens('m',[1,1],'var',[1 3]);
%  show(dens)
%
% See also GAUSSDENS, BALLDENS, PCADENS, DIAGDENS/LEARN, DENSITY


s = struct('m',[],'isd',[]);
c = class(s,'diagdens',density);

if nargin>0
    c=set(c,varargin);
end