function c = learn(c,x,w)
%LEARN Learn the mean and variance of a diagdens density object
%
% c = learn(c,x)
% returns a diagdens object with the mean an variance 
% of the data matrix x, assuming the columns of x are independent, wich leads to
% zeros in the off-diagonal terms.
%
% c = learn(c,x,w)
% computes the weighted mean and variance with the vector of weights w.
%
% See also DIAGDENS, DENSITY/LEARN


[n,d] =size(x);
c = setdim(c,d);

if nargin<3
    w = ones(n,1);
end

counts = sum(w)+1e-320;
c.m	= sum(x.*repmat(w,1,d),1)'/counts;
xc  = x - ones(n,1)*c.m';      
c.isd = 1./sqrt(eps+sum((xc.^2).*(w*ones(1,d)))/counts);
