function dens = mixcommonparams(dens1,otherdens,commonparams,prop)
%MIXCOMMONPARAMS mix the common parameters of densities
%
% dens = mixcommonparams(dens1,nbcommonparams,otherdens)
% dens1 : density object
% commonparams : name of the common parameter
%       available name is 'S' (the covariance matrix are equal)
% prop : proportions (weights for each 
% otherdens is a cell array of densities)
% dens : cell array of resulting densities
%
% used in EM algorithm (method learn)
% 
% See also DIAGDENS, DIAGDENS/N_PARAMS

d=getdim(dens1.density);
dens = {dens1,otherdens{:}};
ndens = length(dens);
indivcov = zeros(ndens,d);

for k=1:ndens
    indivcov(k,:) = dens{k}.isd.^(-2);
end

commonsd = 1./sqrt(sum((prop(:)*ones(1,d)).*indivcov));

for k=1:ndens
    dens{k}.isd = commonsd;
end