function [lval,grad,H] = derloglik(c,x,w)
% DERLOGLIK normalized log-likelihood, gradient, and hessian according to parameters
%
% [lval,grad,H] = DERLOGLIK(c,x)
%
% See also DENSITY/LOGVALUE, DENSITY/LOGLIK
%   UNSUPERVISED, STATLEARN


[n,d] = size(x);

if nargin<3
    w=ones(n,1);
end

counts = sum(w);

xc  = (x - repmat(c.m',n,1));
xcc  = xc*c.R';
lval = counts*(-d/2*log(2*pi) + sum(log(diag(c.R)))) - ...
    .5*sum(sum(xcc.^2,2).*w);

if nargout>1
    meanx  = xc'*w;    
    meanxR  = c.R*meanx;    
    RmeanxR = c.R'*meanxR;
    IJ = c.indR(d+1:end);
    npoff = length(IJ);
    [I,J]=ind2sub([d,d],IJ);  
    %    J = J(d+1:end);
    %    I = I(d+1:end);
    dR = diag(c.R);
    grad = ([RmeanxR ; counts./dR - (xc.*xcc)'*w ; -(xc(:,J).*xcc(:,I))'*w]);
end

if nargout>2
    prodsx  = xc'*(xc.*(w*ones(1,d)));  

    mm = -counts*c.R'*c.R;
    mD = c.R'.*((ones(d,1)*meanx')) + diag(meanxR);
    DD = diag(-counts./dR.^2 - diag(prodsx));
    
    if d==1
        H = [mm,  mD;...
                mD', DD];
    else
        mE = (ones(d,1)*meanx(J,:)').*c.R(I,:)';
        inds = sub2ind([d,npoff],J,(1:npoff)');
        mE(inds) = mE(inds) + meanxR(I);
        
        DE = zeros(d,npoff);
        inds = sub2ind([d,npoff],I,(1:npoff)');
        DE(inds) = -prodsx(IJ);
        
        mat=ones(npoff,1)*I';[ii,jj]=find(tril(mat==mat'));
        EE=zeros(size(mat));
        EE(sub2ind([npoff,npoff],ii,jj))=-prodsx(sub2ind([d,d],J(ii),J(jj)));
        EE=EE+EE'-diag(diag(EE));
        
        H = ([mm,  mD,  mE;...
                mD', DD,  DE;...
                mE', DE', EE]);    
    end
end

%% if one wishes to test the previous code, it is possible to compare with the numeric approximation:
% R = [1 2 3 4;0 4 5 6;0 0 6 7;0 0 0 1];S=inv(R*R');g=gaussdens('var',S);
% [a,b,c]=derlogliknumeric(g,[2 3 5 7]);[a1,b1,c1]=derloglik(g,[2 3 5 7]);num2str([c,zeros(size(c,1),1),c1].*(abs([c,zeros(size(c,1),1),c1])>.0001),2)


