function c=gaussdens(varargin)
%GAUSSDENS Create a multivariate gaussian distribution
%
% c=GAUSSDENS
% returns a empty gaussian density object. Such empty objects can be used
% functions like 'learn(gaussdens,x)' that directly affects parameters to the
% density. 
% 
% c=GAUSSDENS('m',M)
% c=GAUSSDENS('var',v)
% c=GAUSSDENS('m',M,'var',S)
% returns a diagonal gaussian with mean M and covariance matrix S.
%
% Example:
%  dens = GAUSSDENS('m',[1,1],'var',[1 1 1 4]);
%  clf;show(dens,'show_points',1)
%
% See also 
% - BALLDENS, DIAGDENS, PCADENS, DENSITY
% - GAUSSDENS/LEARN, GAUSSDENS/RAND, GAUSSDENS/STATS


s = struct('m',[],'R',[],'indR',[]);
c = class(s,'gaussdens',density);

if nargin>0
    c=set(c,varargin);
end