function [vindiv,vcommon] = getparamsfamily(dens,densrem,name)
%GETPARAMSFAMILY Vector of parameters for a set of gaussdens objects
%
% [vindiv,vcommon] = GETPARAMSFAMILY(dens,densrem)
% returns a pxK matrix vindiv of individual parameters 
% and a vector vcommon of common paramters. dens is the first gauss object, densrem are 
% the K-1 remaining gaussdens
%
% See also GAUSSDENS/SETPARAMSFAMILY
% GAUSSDENS/GETPARAMS, STATLEARN, UNSUPERVISED, DENSITY/ML_LEARN

vcommon = dens.R(dens.indR);
d = getdim(dens);
K = length(densrem)+1;
vindiv = zeros(d,K);

vindiv(:,1) = dens.m;
for k=2:K
    vindiv(:,k) = densrem{k-1}.m;
end

if nargin<=1
    vindiv=[vindiv(:);vcommon(:)];
end