function c = learn(c,x,w)
%LEARN learn the mean and variance of a gaussian density
%
% c = learn(c,x)
% returns a gaussdens object with the mean an variance 
% of the data matrix x. In fact, only the Cholesky decomposition 
% of the covariance matrix is stored in the object, but it is 
% transparent for the user.
%
% c = learn(c,x,w)
% computes the weighted mean and variance with the vector of weights w.
%
% See also GAUSSDENS, DENSITY/LEARN


[n,d] =size(x);
c.density = setdim(c.density,d);
c.indR = trilind(d);

if nargin<3
    w = ones(n,1)/n;
end

counts = sum(w);
c.m	= sum(x.*repmat(w,1,d))'/counts;
xc  = x - repmat(c.m',n,1);
S	= eye(d)*eps+(repmat(w,1,d).*xc)'*xc/counts;

c.R = inv(chol(S)');

return


U=chol(S);
[Q,T] = qr(U);
T(sub2ind([d,d],1:d,1:d)) = max(diag(T),eps);
c.R = inv(T');