function c=LINEARTRANSFORM(c,s)
%LINEARTRANSFORM   Linear transformation of a gaussian distribution
%
% c=LINEARTRANSFORM(c,s) applies a linear transformation on the 
% the distribution
% If s is a scalar:
%  - the mean is multiplied by s,
%  - the cholesky decomposition of inverse covariance matrix is divided by s
%
% c=LINEARTRANSFORM(c,S)
% If S is a matrix of size(dxd):
%  - the mean m is multiplied by S: new_m=S*m,
%  - the cholesky decomposition of inverse covariance matrix R is divided by S: new_R = R*S^(-1)
%
% c=LINEARTRANSFORM(c,V)
% If V is a matrix (or vector) of size(dxr), with r<d, it performs a projection of 
% the density on the vectors defined by the columns of V
%  - the mean m is multiplied by V: new_m=V*m,
%  - the cholesky decomposition of inverse covariance matrix R is 'divided' by V with the function 
% the function MLDIVIDE
%
% See also DENSITY/TRANSLATE, DENSITY/LINEARTRANSFORM, MLDIVIDE,
%   DENSITY, UNSUPERVISED, STATLEARN

c.m = s' * c.m(:);
c.R = c.R/s';
