function [lval,grad] = logvalue(c,x)
% LOGVALUE - Log-density and parameters gradient of samples
%
% lval = LOGVALUE(c,x) 
%   returns the log value of the density at points x in a column vector
% 
% [lval,grad] = LOGVALUE(c,x) also returns the gradient according to
% parameters in a nxnp matrix (np in the number of parameters)
%
% See also DENSITY/LOGVALUE, DENSITY, DENSITY/DERLOGLIK, GAUSSDENS/DERLOGLIK
%   UNSUPERVISED, STATLEARN


[n,d] = size(x);

xc  = (x - repmat(c.m',n,1));
xcc  = xc*c.R';

lval = -d/2*log(2*pi) + sum(log(abs(diag(c.R)))) - ...
                .5*sum(xcc.^2,2);
if nargout>1
    [I,J]=ind2sub([d,d],c.indR);    
    dR = diag(c.R);
    grad = [xcc*c.R , ones(n,1)*(1./dR') - xc.*xcc , -xc(:,J(d+1:end)).*xcc(:,I(d+1:end))];
end


