function dens = mixcommonparams(dens1,otherdens,commonparams,prop)
%MIXCOMMONPARAMS mix the common parameters of densities
%
% dens = mixcommonparams(dens1,nbcommonparams,otherdens)
% dens1 : density object
% commonparams : name of the common parameter
%       available name is 'S' (the covariance matrix are equal)
% prop : proportions (weights for each 
% otherdens is a cell array of densities
% dens : cell array of resulting densities
%
% used in EM algorithm (method learn)

prop = prop./sum(prop);
d=getdim(dens1.density);
dens = {dens1,otherdens{:}};
ndens = length(dens);
indivcov = zeros(d,d,ndens);
for k=1:ndens
    R = real(dens{k}.R);
    dR = diag(R);
    R(sub2ind([d d],1:d,1:d))=max(dR,1e-5*max(dR));
    indivcov(:,:,k) = inv(R'*R);
end

commoncov = sum(repmat(reshape(prop,[1,1,ndens]),d,d).*indivcov,3);
U=chol(commoncov);
[Q,T] = qr(U);
T(sub2ind([d,d],1:d,1:d)) = max(diag(T),eps);
commonR = inv(T');


for k=1:ndens
    dens{k}.R = commonR;
end
