function c = set(c,varargin)
%SET Set the parameters of a gaussian density
%
% a = set(a,'m',M)
% set the mean to te value M;
%
% a = set(a,'var',S)
% set the covariance matrix to te value S;
%
%See also GAUSSDENS/GET, DENSITY/GET, DENSITY/SET

if ~isempty(varargin) & iscell(varargin{1})
    varargin=varargin{1};
end

d=getdim(c.density);
for i=1:2:length(varargin)
    switch varargin{i}
        case 'var'
            var = varargin{i+1};
            if isempty(d) | d==0
                d=length(var);
            else
                if length(var)==1
                    var=eye(d)*var;
                elseif length(var(:))==d
                    var=diag(d);
                else
                    var=reshape(var,[d,d]);                    
                end                
            end
            U=chol(var);
            [Q,T] = qr(U);
            T(sub2ind([d,d],1:d,1:d)) = max(diag(T),1e-320); %avoid singular matrix
            c.R = inv(T');
            if isempty(c.m)
                c.m=zeros(d,1);
            end
            if length(c.m)~=d
                error('mean and variance dimensions do not match');
            end
        case 'm'
            c.m = varargin{i+1}(:);
            d=length(c.m);
            if isempty(c.R)
                c.R=eye(d);
            end
            if length(c.R)~=d
                error('mean and variance dimensions do not match');
            end
        otherwise
            error(['invalide parameter ' varargin{i}]);
    end    
end

c=setdim(c,d);

