function c = learn(c,x,w)
% LEARN - Estimate the proportions of bernoulli variables
%
% Use a bayesian estimation of the proportions (uniform prior):
%   prop = (n_occurence+.5)/(n_data+1)
%
% c = learn(c,x)
%
% c = learn(c,x,w)
%
% See also DENSITY/LEARN


[n,d] =size(x);
c = setdim(c,d);

if nargin<3
    w = ones(n,1);
end
counts = sum(w)+1e-320;
%c.tau = (sum((x.*repmat(w,1,d)),1))/(counts);
opt = optimset;
for i=1:d
    f=inline('(sum(P2./(x-(1-P1)./(1-2*P1)))+1-2*x).^2',2);
    ii = find(x(:,i)~=.5);
    if isempty(ii)
        c.tau(i) = .5;
    else
        [c.tau(i),val] = fminbnd(f,0,1,opt,x(ii,i),w(ii));
    end
end