function c=coordchange(c,rot,transl,epsi)
% COORDCHANGE Change the coordinate system of a mixture of gaussian density
% 
% c=coordchange(c,rot)
% return a MixtDens object containing PCADens objects as clusters with the directions specified in rot
% rot: orthonormal system of vectors defining the directions of the variables
%
% c=coordchange(c,rot,transl)
% transl: vector of translation
%
% c=coordchange(c,rot,transl,epsi)
% epsi: off-variance parameter

if nargin<3 | isempty(transl)
    transl=0;
end
if nargin<4
    epsi=eps;
end

if any(rot'*rot-eye>10*eps)
    warning('The rotation matrix is not orthonormal');
end

d0=c.density.d;
d=size(rot,1);
dif=d-d0;

for k=1:length(c.p)
   [m,S] = stats(c.densities{k});
   [V,D] = eig(S);
   c.densities{k} = PCADens('m',rot*m+transl,'V',rot*V,'lambda',diag(D),'offvar',epsi);
end

c.density.d = d;