function [lval,grad,H] = derloglik(c,x,w)
% DERLOGLIK log-likelihood, gradient, and hessian according to parameters
%
% [lval,grad,H] = DERLOGLIK(c,x) returns a scale value lval
% (log-likelihood, as in DENSITY/LOGLIK, a npx1 vector of gradients,
% and a npxnp hessian matrix
%
% 
%
% See also DENSITY/LOGVALUE, DENSITY/LOGLIK
%   UNSUPERVISED, STATLEARN

[n,d] = size(x);
K = length(c.p);

if nargin<3
    w=ones(n,1);
end
counts = sum(w);


if isempty(c.commonparams)
    lv = zeros(n,K);
    for k=1:K
        lv(:,k) = logvalue(c.densities{k},x);
    end
    val = exp(lvdens)+1e-320;
    tau = (ones(n,1)*c.p).*val;
    sumprob = sum(tau,2);
    lval = log(sumprob)'*w;    
    tau = tau./(sumprob*ones(1,K));
    
    wt = (w*ones(1,K)).*tau;
    lvdens = zeros(1,K);    
    [lvdens(1),graddens0,hessdens0] = derloglik(c.densities{1},x,wt(:,1));
    np=length(graddens0);np2=np^2;
    graddens = zeros(np,K);graddens(:,1)=graddens0;
    hessdens = zeros(np,np,K);hessdens(:,:,1)=hessdens0;

    npK=np*K+~c.knownp;
    grad = zeros(npK,1);
    H = zeros(npK,npK);        
    wt2 = wt.*(1-tau);
    for k=2:K
        ind = (1:np)+(k-1)*np;
        [lvdens(k),grad(ind),H(ind,ind),M] = derloglik(c.densities{k},x,wt(:,k));
        H(ind,ind) = H(ind,ind) + M
    end
else
    error('commonparams not implemented yet');
end

if ~c.knownp
    grad = [grad;(tau(:,1:end-1)-ones(n,1)*c.p(1:end-1))'*w];
end