function v = get(c,pname)
% GET - Get some parameters of a mixture distribution
% 
% v = GET(c,st)
% parameters are get by their name is a string st
%
% v = GET(c,'prop',p) get the proportions of the clusters to p
% v = GET(c,'commonparams') get the name of the common parameters
%
% IMPORTANT : OTHER PARAMETER VALUES
% The parameter of the components can be get in matrices by simply specifying the name
% which is passed to the method get of the component.
% for example,
% c = GET(c,'m')
% returns a d*K matrix containing the means of the components
%
% Example
% -------
%
% % mixture of full-covariance gaussian and spherical gaussian with specified parameters
% c = mixtdens({gaussdens('m',[1;2],'var',[1 1;1 4]),balldens('m',[2,5],'var',2)})
% c = GET(c,'p') % get the proportions of the clusters
% c = GET(c,'m') % get the means in a 2*2 matrix
% c = GET(c,'R') % error because the parameter 'R' is only defined for the first component
%
% See also MIXTDENS/GET, DENSITY, MIXTDENS/LEARN, CLUSTERING, MIXTDENS, UNSUPERVISED, STATLEARN


switch pname
    case 'K'
        v = length(c.densities);        
    case 'p'
        v = c.p;        
    case 'densities'
        v = c.densities;                
    case 'dim'
        v = getdim(c);
    case 'commonparams'
        v = c.commonparams;
    otherwise
        K = length(c.densities);
        par0 = get(c.densities{1},pname);
        sz  = size(par0);        
        nd=sum(size(par0)>1);
        if nd<=1
            v = zeros(length(par0),K);
            v(:,1) = par0(:);
            for k=2:K
                M = get(c.densities{k},pname);
                if any(sz ~= size(M))
                    error(['The dimensions of the parameter ' pname ' are not always the same']);
                end
                v(:,k) = M;
            end
        elseif nd==2
            v = zeros(sz,K);
            v(:,:,1) = par0;
            for k=2:K
                M = get(c.densities{k},pname);
                if any(sz ~= size(M))
                    error(['The dimensions of the parameter ' pname ' are not always the same']);
                end
                v(:,:,k) = M;
            end
        else 
            error(['The number of dimensions of the parameter ' pname ' cannot be greater than 2']);
        end
end
