function c = learn_partialcl(c,x,w,cl,varargin)
%LEARN Learn the paremeters by EM with partial clustering
%   
% c = learn_partialcl(c,x,w,cl,varargin)
% 
% See also MIXTDENS/LEARN

[n,d] = size(x);
c.density = setdim(c.density,d);

%parameters
niter = 30;
if nargin<4 | isempty(cl)
    cl = ones(n,K);
end

%weights
if nargin<3 | isempty(w)
   w = ones(n,1)/n; %equal weights
end
if ~isnumeric(w)
    varargin={w,varargin{:}};
    w = ones(n,1)/n; %equal weights    
end

K = size(cl,2);
c.p=ones(1,K)/K;
display = n>5000;
epsi = 1e-4;

%%% PARAMETERS MANAGEMENT
for i=1:2:length(varargin)
    if ~isstr(varargin{i}) | ~exist(varargin{i},'var')
        error(['Invalid parameter ' varargin{i}]);
    end
    eval([varargin{i} '= varargin{i+1};']);
end
%%%


%---------------------------------------------------------------------------------------------------------------------------------------------
% INITIALIZATION
%---------------------------------------------------------------------------------------------------------------------------------------------

if length(c.densities) ~= K | isempty(getdim(c.densities{1}));    
    dens = c.densities{1};    
    for k=1:K
        c.densities{k} = dens;
    end
    [m,aff] = kmeanspartialcl(x,cl,'optimal_init');
    om0=zeros(n,K);
    om0(sub2ind([n,K],1:n,aff))=1;
else
    for k=1:K
        om0(:,k) = c.p(k)*value(c.densities{k},x)+eps;
    end
    om0 = om0.*cl;
    om0 = om0./repmat(sum(om0,2),1,K); %normalize the lines    
end

%---------------------------------------------------------------------------------------------------------------------------------------------

ll=-1e-320;

maxrestart = 5;
c.densities{1} = learn(c.densities{1},x);
mincounts = n_params(c.densities{1})-d;
om=om0;
if mincounts*K>n
    warning(['' num2str(n) ' data are not enough to learn a mixture of ' num2str(K) ' densities with ' num2str(n_params(c.densities{1})) ' parameters']);
    niter = 2;
end

convg=0;
it=2;
restart=0;
ntot = sum(cl);
while(it<=niter+1) %beginning of the loop    
   
    counts = sum(om);
    c.p = max(.001,counts);
    c.p=c.p/sum(c.p);
    
    for k=1:K
            if counts(k)<mincounts & restart <5 %if few data in a cluster                
                c.densities{k} = learn(c.densities{k},x,1./max(om0,[],2));
                restart = restart+1;
                counts(k+1:end)=counts(k+1:end)+mincounts;                
                it=2;
            else
                c.densities{k} = learn(c.densities{k},x,om(:,k));
            end                
    end
    
    if ~isempty(c.commonparams)  %dependents parameters       
        c.densities = mixcommonparams(c.densities{1},c.densities(2:end),c.commonparams,c.p);
    end
    

    for k=1:K
        om0(:,k) =value(c.densities{k},x)+eps;
    end
    
    pp=(ones(n,1)*c.p).*cl;
    pp=pp./(sum(pp,2)*ones(1,K));
    om0 = om0.*cl;
    
    %log-likelihood  
    ll(it) = sum(log(sum(om0')));
    convg = (abs(ll(it)-ll(it-1))<epsi*n | restart>maxrestart);
    if convg % stop test : 
        break      
    end
    
    %normalization of the rows to obtain probabilities of belonging to each class for every data
    om = om0./repmat(sum(om0,2),1,K); %normalize the lines
    if display==2
        disp([num2str(it) ' ll = ' num2str(ll(it))]); %display the iterations of the EM algorithm
    end
    it=it+1;
end 


if display
    %fprintf('d=%d,n=%d,K=%d==>np=%d\n',d,n,K,n_params(c));
    if restart>maxrestart
        disp(['EM cannot convergence due to infinite maximum likelihood (' num2str(K) ' groups)']);        
    elseif convg 
        disp(['EM convergence in ' num2str(it) ' iterations (' num2str(K) ' groups)']);
    else
        disp(['EM stopped before convergence in ' num2str(niter) ' iterations (' num2str(K) ' groups)']);
    end
end
