function [lval,grad] = logvalue(c,x)
% LOGVALUE - Log-density and parameters gradient of samples
%
% lval = LOGVALUE(c,x) returns a nx1 vector of log-densities computed on
% each data point (rows of x)
%
% [lval,grad] = LOGVALUE(c,x) aslso returns a nxnp matrix of gradient
% values at the points x
%
% See also DENSITY/LOGLIK, DENSITY/ML_LEARN, DENSITY,
%   UNSUPERVISED, STATLEARN

if nargin>2
    warning('weights have to be implemented');
end

[n,d] = size(x);
K = length(c.p);

if nargout<=1
    lv =zeros(n,K);
    for k=1:K
        lv(:,k) = logvalue(c.densities{k},x);
    end
    val = exp(lv)+1e-320;
    tau = (ones(n,1)*c.p).*val;
    sumprob = sum(tau,2);
    lval = log(sumprob);        
else
    [lv(:,1),gd] = logvalue(c.densities{1},x);
    np = size(gd,2);
    gd = repmat(gd,[1,1,K]);
    for k=2:K
        [lv(:,k),gd(:,:,k)] = logvalue(c.densities{k},x);
    end
    val = exp(lv)+1e-320;
    tau = (ones(n,1)*c.p).*val;
    sumprob = sum(tau,2);
    lval = log(sumprob);
    
    tau = tau./(sumprob*ones(1,K));
    lastcol = tau(:,1:end-1)-ones(n,1)*c.p(1:end-1);
    if isempty(c.commonparams)
        grad = [reshape(gd.*repmat(reshape(tau,[n,1,K]),1,np),[n,np*K]),lastcol];
    else        
        gd = gd.*repmat(reshape(tau,[n,1,K]),1,np);
        icommon = indcommonparams(c.densities{1},c.commonparams);
        iind = setdiff(1:np,icommon);
        nc=length(icommon);
        ni=np-nc;
        grad = [...
            reshape(gd(:,iind,:).*repmat(reshape(tau,[n,1,K]),1,ni),[n,ni*K]),...
            sum(gd(:,icommon,:).*repmat(reshape(tau,[n,1,K]),1,nc),3),...    
            lastcol];
    end
end

