function c=set(c,varargin)
% SET Set the parameters of a mixture distribution
% 
% c= SET(c,...,'parname',V,...)
% parameters are set by pairs parameters name/parameter value
% possibles paramters names
%
% c= SET(c,...,'prop',p,...) set the proportions of the clusters to p
%
% c= SET(c,...,'commonparams' ,V,...) set the proportions of the clusters to p
% force the parameter specified as a string in V to be the same for all the
% mixture components.
%
% IMPORTANT : AFTER THESE MIXTURE PARAMETERS
% The parameter of the components can be set by simply specifying the name
% that is passed to the method SET of the component.
% for example,
% c= set(c,'commonparams','var','m',[0,2])
% return mixture of 2 densities (already specified in c) with means 0 and 2
%
% Example
% -------
%
% % mixture of full-covariance gaussian and spherical gaussian with specified parameters
% c = mixtdens({gaussdens('m',[1;2],'var',[1 1;1 4]),balldens('m',[2,5],'var',2)})
% c = set(c,'p',[.4 .6]) % set the proportions of the clusters
% c = set(c,'m',[1,2;3 4]') %set the means to [1;2] and [3;4]
% c = set(c,'p',[.4 .6],'m',[1,2;3 4]') % is equivalent to the 2 previous lines
%
% See also DENSITY, MIXTDENS/LEARN, CLUSTERING, MIXTDENS, UNSUPERVISED, STATLEARN

if isempty(varargin)
    return
end

commonparams = [];
K=length(c.p);
densities=c.densities;
prop = [];
p=[];
knownp = [];

dens_args=[];
%%% PARAMETERS MANAGEMENT
if ~isempty(varargin) & iscell(varargin{1}),varargin=varargin{1};end
for i=1:2:length(varargin)
    if ~isstr(varargin{i}) | ~exist(varargin{i},'var')
        dens_args=varargin(i:end);
        break
    else
        eval([varargin{i} '= varargin{i+1};']);
    end
end
%%%

if ~isempty(prop)
    warning('prop parameter will be obsolete in future versions of statlearn, use ''p'' instead');
    p=prop;
end

if ~isempty(p)
    c.p=p(:)';
    K=length(c.p);
end

if ~isempty(knownp)
    c.knownp=knownp;
end

if isempty(K)| K==0
%    K = length(densities);
end

%if ~iscell(densities) | K~=length(densities)
%     K = size(dens_args{2});K = K(end);
%     densities = densities(ones(1,K))
% end

% if length(densities)~=K & K~=0
%     dens = densities{1};
%     densities = cell(1,K);
%     for k=1:K
%         densities{k} = setdim(dens,getdim(c));
%     end
%     if isempty(c.p)
%         c.p = [ones(1,K)]/K;
%     end    
% end

if ~isempty(dens_args)
    if iscell(densities)        
        densities=densities{1};
    end
    K = size(dens_args{2});K = K(end);    
    args = dens_args;
    c.densities = cell(1,K);
    for k=1:K
        for a=2:2:length(args)
            nd=sum(size(dens_args{a})>1);
            if nd==1
                args{a} = dens_args{a}(k);
            elseif nd==2
                args{a} = dens_args{a}(:,k);
            else
                args{a} = dens_args{a}(:,:,k);
            end
        end
        c.densities{k}=set(densities,args);        
    end
    c = setdim(c,getdim(c.densities{1}));
    if isempty(c.p)        
        c.p = [ones(1,K)]/K;    
    end;
end
if ~iscell(c.densities)        
    c.densities={c.densities};
    c.densities=c.densities(ones(1,K));
else
    c = setdim(c,getdim(c.densities{1}));
end

if ~isempty(commonparams)
    c.commonparams = commonparams;
    if length(c.p)>1 & getdim(c.densities{1})>0
        c.densities=mixcommonparams(c.densities{1},c.densities(2:end),commonparams,c.p)
    end
end

if length(c.p)~=length(c.densities)
    error('The number of proportions and the number of densities are different.')
end
