function c=set(c,varargin)
%SET Set the parameters
%
% The arguments are given by pairs.
% c = PCADENS(...,'r',r,...) number of principal components
% c = PCADENS(...,'m',m,...) mean of the density
% c = PCADENS(...,'proj_mat',V,...) dxr matrix of principal components
% c = PCADENS(...,'lambda',lbd,...) vector of the variances in the principal directions (minus the noise variance)
% c = PCADENS(...,'noise',s,...) scalar value equal to the off-variance,
%   i.e. the variance in the orthogonal space of the principal components
% See also PCADENS, DENSITY, UNSUPERVISED, STATLEARN

m = [];
r = [];
proj_mat = [];
lambda = [];
noise = [];
dim=[];
d = getdim(c);


%%% PARAMETERS MANAGEMENT
if ~isempty(varargin) & iscell(varargin{1}),varargin=varargin{1};end
for i=1:2:length(varargin)
    if ~isstr(varargin{i}) | ~exist(varargin{i},'var')
        error(['Invalid parameter ' varargin{i}]);
    end
    eval([varargin{i} '= varargin{i+1};']);
end
%%%

c.proj_mat = proj_mat;

if ~isempty(proj_mat)
    [d,r] = size(proj_mat);
end


if isempty(m)
    c.m = zeros(d,1);
else
    d = length(m);    
    c.m=m(:);
    if isempty(r)
        r=0;
    end
end

if isempty(c.proj_mat)
    c.proj_mat = [eye(r);zeros(d-r,r)];
end

if isempty(noise) & ~isempty(d)
    c.noise = 1;
else    
    c.noise = noise;
end


if ~isempty(lambda)
    r = length(lambda);
    c.lambda = lambda(:)';
    if isempty(proj_mat)
        c.proj_mat = [eye(r);zeros(d-r,r)];
    end
end

c = setdim(c,d);
