function c = learn(c,x,w,varargin)
%LEARN Learn the parameters of the LowDimDens object
%
% c = learn(c,x,w)
% c: LowDimDens object
% x: nxd-dimensional data
% w: nx1 vector of weights (ones by default)
% Learn the rotation and translation parameters by first reducing the space in rdimensions
% (equal to LowDimDens/getlowdim) by PCA, and then learn the incorporated density 
% (see getdens) with their standard 'learn' method. Note that this does NOT
% correspond to the maximum likelihood estimation of the parameters.
% 
% c = learn(c,x,w,'display',0)
% switch off the display
%
% c = learn(c,x,w,'prop_inert',p)
% sets the proportion of inertia to keep


[n,d] = size(x);
c=setdim(c,d);

if nargin<3 | isempty(w)
   w = ones(n,1)/n; %equal weights
end


display = 1;

for i=1:2:length(varargin)
    if ~exist(varargin{i},'var')
        error(['Invalid parameter ' varargin{i}]);
    end
    eval([varargin{i} '= varargin{i+1};']);
end

%get the number of dimensions to keep
r=getdim(c.inc_dens);

if isempty(r) | r==0
    prop_inert = .9;
    ev = eig(cov(x));ev=ev(end:-1:1);
    cs = cumsum(ev/sum(ev));
    f=find(cs>prop_inert);
    r = f(1);
    if display
        fprintf('Covariance eigenvalues: [%s]\n==> %d dimension catch %d%% of the variance\n',...
            num2str(ev(:)'),r,prop_inert*100);
    end
end

%reduce the dimensionality of the data and save the transformation parameters
[xred,c.proj_mat,c.off_var,c.offset] = reducedim(x,r);

%learn the density in the r-dimensional space
c.inc_dens = learn(c.inc_dens,xred,w);

c.off_var=c.off_var;
