function c=LowDimDens(dens,varargin)
% LOWDIMDENS LowDimDens object constructor : density defined in a low-dimensional hyperspace
%
% LowDimDens are densities in a vectorial space of dimension d wich essentially lives in a 
% r-dimensional subspace (r<d). The density in the orthogonal space (of dimension d-r) is considered
% to be gaussian with a small variance epsi.
%
% c=LowDimDens(dens)
% c=LowDimDens(dens,...)
% Defines a LowDimDens object where r is the dimension of the density
% object dens
%
% c=LowDimDens(...,'data',X,...)
% specify the data from wich the density has to be learn.
% 
% c=LowDimDens(...,'r',r,...)
% set the dimension of the density dens (the low dimension). 
%
% c=LowDimDens(...,'d',d,...)
% set the dimension of the data (the high dimension). 
% 
% c=LowDimDens(...,'proj_mat',proj_mat,...)
% set the projection matrix of the subspace.
%
% c=LowDimDens(...,'off_var',off_var,...)
% set the off-variance parameter that models the noise in the orthogonal
% space.
%
% c=LowDimDens(...,'offset',offset,...)
% set the offset (center) of the density in the d-dimensional space.


r=[];
d=[];
data=[];
proj_mat=[];
off_var=[];
offset=[];

%%% PARAMETERS MANAGEMENT
for i=1:2:length(varargin)
    if ~isstr(varargin{i}) | ~exist(varargin{i},'var')
        error(['Invalid parameter ' varargin{i}]);
    end
    eval([varargin{i} '= varargin{i+1};']);
end
%%%

if isstr(dens)
    name = densities;
    dens = eval([name ';']);
end

if ~isempty(r)
    dens = setdim(dens,r);
end

if ~isempty(proj_mat)
    [d,r] = size(proj_mat);
    off_var=.1;
    offset=zeros(d,1);
end


s = struct('inc_dens',dens,'proj_mat',proj_mat,'off_var',off_var,'offset',offset);
c = class(s,'lowDimDens',density);

if ~isempty(d)
    c.density.d = d;
end

if ~isempty(data)
    c=learn(c,data);
end
