function res = gradientchek(g0,x)
%GRADIENTCHECK Check if the built-in density gradient computation valid
%
% gradientchek(g0) 
%  display the results of the comparaison between local
%  log-gradient approximation and the function 'logvalue' of the density g0. 
% The gradient is evaluated at 100 random points.
%
% gradientchek(g0,x) evaluates the gradient in the points in the nxd matrix x
%
% res=gradientchek(g0,x) returns 0 or 1

if nargin<2
    x=rand(g0,100)
end

[n,d] = size(x);

eps=1e-10;
tol = 1e-5;

[ll,der] = logvalue(g0,x);
p=size(der,2);
der=sum(der,1)';

for i=1:100
    dir = randn(p,1);
    dir=dir/norm(dir);
    g=g0;
    params = getparams(g);
    g = setparams(g,params+eps*dir);    
    [ll2,der2] = logvalue(g,x);
    ll2=sum(ll2);
    der2=sum(der2)';
    if ~approxeq(ll+eps*(dir'*der),ll2,tol)        
        if nargout==0
            disp('Gradient invalid');
        else
            res=0;
            return
        end
    end
end
if nargout==0
    disp(['The gradient of class ' class(g0) ' seems to be correct']);
else
    res=1;
end

function r=approxeq(a,b,t)
    r = sum(abs(a(:)-b(:)))<t;
    