function [v,grad] = neglldensity(params,c,x)
%NEGLLDENSITY Negative log-likelihood given parameters, density and data
%
% [v,grad] = neglldensity(params,c,x)
% Returns the negative log-likelihood of the density c with parameters 
% params and on data x. This function is used as an objective function 
% to optimize the likelihood (for example in DENSITY/ML_LEARN).
%
% Example
% -------
% % MAXIMUM LIKELIHOOD ESTIMATION BY GRADIENT DESCENT
% %random points from a mixturedistribution 
% x=rand(mixtdens_example,300); 
% % initial distribution (use of kmeans clustering to get the means)
% mxt0 = mixtdens(gaussdens,3,'m',kmeanslight(x,3)); 
% % initial distribution plot
% clf;
% subplot(211);
% show(mxt0,x); 
% title('Initial distribution');
% % maximum likelihood solution
% sol = fminunc('neglldensity',getparams(mxt0),optimset('GradObj','on'),mxt0,x); 
% % parameters transformation into a mixture distribution
% mxt1 = setparams(mxt0,sol); 
% % plot the resulting distribution
% subplot(212);
% show(mxt1,x);
% title('Maximum Likelihood by gradient descent');
%
%
% See also DENSITY/ML_LEARN

c = setparams(c,params);
[v,grad] = logvalue(c,x);
v=-sum(v)';
grad=-sum(grad)';
