function [affect,dist2] = closestmeans(x,m,nb)
% CLOSESTMEANS - Affects points to the closest means
%
% A = CLOSESTMEANS(X,M) X is a nxd matrix and M a dxK matrix
%   A contains the indexes of the m column wich is the closest to the points
%
% A = CLOSESTMEANS(X,M,C) C is an integer: returns the C closest affectations
%   in increasing order
%
% [A,D2] = CLOSESTMEANS(X,M) and [A,D] = CLOSESTMEANS(X,M,C) 
%   returns the matrix of closest squared distances in D2
%   it is therefore increasing
%
% affect = CLOSESTMEANS(x,m) x is a nxd matrix and m a dxK matrix
%   affect containd the indexes of the m column wich is the closest to the points
%
% See also KMEANSLIGHT, PARTIALKMEANS, COLPLOT

[n,d]=size(x);
K = size(m,2);

d2 = sum((x.^2),2)*ones(1,K) +...
    ones(n, 1) * sum((m.^2),1) - ...
    2.*(x*m);

if nargin<3    
    [dist2, affect] = min(d2,[],2);
else
    [dist2, affect] = sort(d2,2);
    affect = affect(:,1:nb);
    dist2 = dist2(:,1:nb);
end