function [m,affect,i] = kmeanspartialcl(x,A,m,niter)
%KMEANSPARTIALCL Trains a k means cluster model with partial clustering.
%
%	M = kmeanspartialcl(X,A);
%   Compute the centers of the kmeans algorithm, using a partial labelling
%   of the data points in the matrix A : if data point i cannot belong to
%   the cluster k, then A(i,k)=0. Otherwise, A(i,k)=1.
%
% See also KMEANS, MIXTDENS/LEARN_PARTIALCL

[n,d] = size(x);
K = size(A,2);
big   = max(abs(x))';

if nargin<3 
    m = x(1:K,:)';    
elseif ~isnumeric(m)
    m = kmeanslight(x,K);
    counts=zeros(K,K);
    pos=sortrows(unique(A,'rows'));
    npos=size(pos,1)-1;
    for i=1:npos
        p = pos(i,:);
        indtemp = find(p);
        Ktemp = sum(p);
        ind = find(sum(abs(A-ones(n,1)*p),2)==0);
        mtemp = kmeanslight(x(ind,:),Ktemp);
        D = sum((m'.^2),2)*ones(1,Ktemp) + ...
            ones(K, 1) * sum((mtemp.^2),1) - ...
            2.*(m'*mtemp);
        [v,indv] = min(D,[],2);
        [vs,inds] = sort(v);
        counts(inds(1:Ktemp),indtemp) = counts(inds(1:Ktemp),indtemp)+1;
    end
    m_old = m; 
    rem=ones(1,K); 
    [null,ord]=sortrows(-counts);
    for k=ord'
        ind = find(rem);
        [v,indv] = max(counts(k,ind));
        m(:,ind(indv(1))) = m_old(:,k);
        rem(ind(indv(1)))=0;
    end        
end

if nargin<4
    niter = 100;    
end






MX = sum((x.^2),2)*ones(1,K)+(~A*sum(big.^2));       

% Main loop of algorithm
for i=1:niter
    % Save old centres to check for termination
    old_m = m;
    
    % Calculate posteriors based on existing centres
    d2 = MX + ...
        ones(n, 1) * sum((m.^2),1) - ...
        2.*(x*m);
    
    % Assign each point to nearest centre
    [minvals, affect] = min(d2');
    for j=1:K
        I=find(affect==j);
        if isempty(I)
            [val,indmax] = max(minvals);
            m(:,j) = x(indmax,:)';
        else
            m(:,j) = mean(x(I,:))';
        end
    end
    
    % Test for termination
    if max(max(abs(m - old_m))) < eps
        break;
    end
end    

