function [x,cl,datasetname] = loaddataset(num,data_directory);
%loaddataset Load real datasets
%
% [x,cl] = loaddataset(dsname)
% load the dataset dsname.txt in the subdirectory dsname
% the last column of the dataset is the class label (return in cl),
% the remaining data ere returned in the nxd matrix x
%
%
% [x,cl,datasetname] = loaddataset(num)
% load the dataset with number num (this is the "dir" function order)
% datasetname is the name of the loaded dataset
% num = loaddataset(0) return the maximal number of datasets
%
% [x,cl,datasetname] = loaddataset(dsname,rootdirect)
% The root directoty can be specified in rootdirect 
% The datasets subdirectory must be in the data root directory
% (/home/bocage/gbouchar/work/data/realdatasets/ by default)

if nargin<2   
    if isunix
        data_directory = '/home/bocage/gbouchar/work/data/realdatasets/';
        sep = '/';
    else
        data_directory = '..\..\data\realdatasets\';
        sep = '\';
    end
end

dirs=dir(data_directory);
if isempty(dirs)
    error([data_directory ' is an invalid data directory'])
end
fnames = {dirs.name}';
ind = find(~(strcmp('..',fnames)|strcmp('.',fnames)) & [dirs.isdir]');
str = fnames(ind);

if nargin==0
    v=0;    
    [s,v] = listdlg('PromptString','Select a dataset:',...
        'SelectionMode','single',...
        'ListString',str);
    datasetname = str{s};
    if ~v        
        return
    end
    
else
    if isstr(num)
        num = find(strcmp(str,num)); %returns the index of the string num in the cell array str
        if isempty(num) 
            disp(['invalid dataset name. Possible names are:']);
            disp(str)
            error('Please enter a valid dataset name.');
        end
    end
    
    if num==0 & nargout<=1
        x=size(str,1);
        return
    elseif num==-1 & nargout<=1
        x=str;
        return        
    elseif num>length(str)
        error(sprintf('They are only %d datasets availables',length(str)));
    else
        datasetname = str{num};    
    end
end

data=load([data_directory datasetname sep datasetname '.txt']);

x=data(:,1:end-1);
x = standardize(x);
cl = data(:,end);
cl = cl-min(cl)+1;

disp([datasetname ' dataset loaded: ' num2str(max(cl)) 'classes, ' num2str(size(x,1)) ' data, ' num2str(size(x,2)) ' dimensions']);    
