function [I,XR] = isinrect(X,R)
% ISINRECT - Find points in a set of rectangles
%
% I = ISINRECT(X,R)
%   returns a vector of 0 and 1 if points wich are or are not in 
%   the rectangle R. Multiple rectangles can be given in R (as many a the number of points)
%
% [I,XR] = ISINRECT(X,R)
%   returns in XR the relative positions of the points in the rectangle
%   (these coordinates are between 0 and 1)
%
% examples:
%
% findpointsinrects([1 1;1 0;2 2;.6 1.3;1.4 .7],[.5 .5 1 1])
% findpointsinrects([0 1;2 2;1 1],[.5 .5 1 1;1.4 1 .7 2;.5 .5 1 1])
% 
% See also FIND, CELL2MAT_AND_LBL

XR = [(X(:,1)-R(:,1))./R(:,3) (X(:,2)-R(:,2))./R(:,4)];
I = (XR(:,1)>=0 & XR(:,2)>=0 & XR(:,1)<1 & XR(:,2)<1);


