function [k,volume] = kernel(x,y,lambda,type,range)
%KERNEL : compute a distance beetween 2 set of points in a d-dimensionnal space
% 
% mat = kernel(X,Y)
%       if X is a matrix of dimension nx*d and y of dimension ny*d, mat is the  nx*ny squared distance matrix of X and Y
%   
% mat = kernel(X,Y,lambda)
%       compute a gaussian kernel with smoothing parameter (standard deviation) having the real value lambda
%
% mat = kernel(X,Y,lambda,type)
%   give other kinds of kernels
%    type must be one of the following string :
%   {'gaussian','quadratic','cosinus','squared_cosinus','triangular','rectangular'};
%   (this cell array of string can be obtained by typing the command kernel without argument)


if nargin == 0
    %k = {'gaussian','quadratic','cosinus','squared_cosinus','triangular','rectangular'};
    k = {'squared_dist','gaussian','exponential','student','triangular','rectangular'};
    return
end

if nargin<3
    lambda=1;
end

if nargin<4
    type = 'squared_dist';
end

if nargin<5
   range = [0,1];
end

[nx,d]=size(x);
ny=size(y,1);

d2 = (ones(ny, 1) * sum((x.^2)', 1))' + ...
  ones(nx, 1) * sum((y.^2)',1) - ...
  2.*(x*(y'));

if strcmp( 'squared_dist',type)
       k=d2;
else
    k = 1/(lambda.^d)*K(sqrt(d2)./lambda,type)*1/sqrt(2*pi)^(d-1);
end
    
if nargout>1
    volume = prod(normcdf(ones(nx,d),x,lambda)-normcdf(zeros(nx,d),x,lambda),2);
end

if any(any(k<1e-6))
  k(k<0) = 0;
end

function v=K(x,type)
switch type
    case 'gaussian'
        v = 1/sqrt(2*pi)*exp(-x.^2/2); %gaussian
    case 'quadratic'
        v = 3/3*(1-x.^2).*(abs(x)<1); %quadratic
    case 'bisquared'
        v = 3/3*(1-x.^2).^2.*(abs(x)<1);; %bi - quadratic
    case 'cosinus'
        v=.5*cos(x).*(abs(x)<pi/2); %cosinus
    case 'squared_cosinus'
        v=2/pi*cos(x).^2.*(abs(x)<pi/2); %squared cosinus
    case 'triangular'
        v=max(2*(1-abs(x)),0); %triangular window
    case 'rectangular'
        v = abs(x)<.5; %rectangular window
    case 'exponential'
        v = exp(-abs(x))/2; 
    case 'student'
        p = 2;
        v = (gamma(p)/gamma(p-.5)/sqrt(pi))./(1+x.^2).^p;
    case 'linear'
        v = x; %rectangular window
    otherwise
        error('invalid type of kernel');
 end
    