function Y = multdim(X,v,dim);
%MULTDIM matrix multiplication by a vector along one dimension
%
% Y = multdim(X,v,dim);
% X : n-dimensional matrix
% v : vector of size 'size(x,dim)'
% dim : integer specifying the dimension along wich the multiplication
% operates (1 by default)
%
% examples : 
% >> multdim(ones(3,3,3),1:3)
% 
% ans(:,:,1) =
% 
%      1     1     1
%      2     2     2
%      3     3     3
% 
% 
% ans(:,:,2) =
% 
%      1     1     1
%      2     2     2
%      3     3     3
% 
% 
% ans(:,:,3) =
% 
%      1     1     1
%      2     2     2
%      3     3     3
%
% >> multdim(ones(3,3,3),1:3,3)
% 
% ans(:,:,1) =
% 
%      1     1     1
%      1     1     1
%      1     1     1
% 
% 
% ans(:,:,2) =
% 
%      2     2     2
%      2     2     2
%      2     2     2
% 
% 
% ans(:,:,3) =
% 
%      3     3     3
%      3     3     3
%      3     3     3


if nargin<3 
   dim = 1;
end

sz = size(X);
nums = ones(1,length(sz));
nums(dim)=length(v);
v=reshape(v,nums);
nums = sz;
nums(dim)=1;
Y = X.*repmat(v,nums);

