function dens = multnormpdf(x,mu,sigma)
%MULTNORMPDF
%
%   dens = multnormpdf(x,mu,sigma)
%	Multivariate normal probability distribution function with identity*constant covariance matrix
%	x : 	  Points where the evaluation is made
%		 	  The number of columns represents the dimension d of the distribution
%		 	  Each line corresponds to a point
%	mu : 	  Mean parameter
%			  Vector with d lines
%			  If multiple columns are given, the return value will have the same number of column, each one representing a different distribution
%	sigma : variance array
%			  Multiple variances must be given in a 3D array
%
%	dens :	  Probability density at the points x(i,:)
[n,d] = size(x);

k = size(mu,2);

for i=1:k
   R = chol(inv(sigma(:,:,i)));
   xcc  = (x - repmat(mu(:,i)',n,1))*R';
   dens(:,i) = 1/(2*pi)^(d/2)*(prod(diag(R))+1e-320)*...
                exp(-.5*sum(xcc.^2,2));
end



