function dens = multnormpdf2(x,mu,sigma)
%MULTNORMPDF2
%
%	Multivariate normal probability distribution function with identity*constant covariance matrix
%	x : 	  Points where the evaluation is made
%		 	  The number of lines represents the dimension d of the distribution
%		 	  Each column corresponds to a point
%	mu : 	  Mean parameter
%			  Vector with d lines
%			  If multiple columns are given, the return value will have the same number of column, each one representing a different distribution
%	sigma : variance array
%			  Multiple variances can be given in a 1D array
%
%	dens :	  Probability density at the points x(:,i)
[d,n] = size(x);
k = size(mu,2);
for i=1:k
   cx = x-repmat(mu(:,i),1,n);
	dens(:,i) = 1/(2*pi)^(d/2)/sqrt(sigma(i)^d)*exp(-.5*sum(((cx'/sigma(i)).*cx')',1))';
end
