function H = colplot(data,varargin)
%COLPLOT plot points with different colors
%
%   colplot(celldata,...)
%       plot each element of celldata in different colors (given by the
%       function cmap). celldata is a cell array of matrix
%       the remaining argument are graphical parameters passed to line
%       function
%
%   colplot(matrix,lbl,varargin)
%       the remaining arguments can be given in a cell array containing
%       pairs of graphical values
%
%   colplot(matrix,lbl,...)
%       plot each element of celldata in different colors (given by the
%       function cmap). celldata is a cell array of matrix
%
%   H = colplot(...)
%       return a cell array of handles to lines of dimension the number of
%       groups
%
%   See also LINE,GET,SET,LDAPLOT.
%cl = cl-min(cl)+1;

if ~iscell(data)
    if nargin==1 | isstr(varargin{1});
        data={data};
    else
        data = lbl2cell(data,varargin{1});
        varargin = varargin(2:end);
    end
end

if ~isempty(varargin) & iscell(varargin{1}) %compatibility with cell array of arguments
        varargin=varargin{1};
end

d = size(data{1},2);
if(d>3)
    warning('More than 3 dimensions. Use LDAPLOT for a lower-dimensionnal representation');
end

K = length(data);
H = zeros(K,1);

for k=1:K
   xcur = data{k};   
   if isempty(xcur)
       continue
   end
   if d==1
       H(k) = line(xcur(:,1),ones(size(xcur,1),1)*eps*k);
   elseif d==2
       H(k) = line(xcur(:,1),xcur(:,2));
   else
       H(k) = line(xcur(:,1),xcur(:,2),xcur(:,3));
   end
   set(H(k),'Marker',marker(k),'LineStyle','none');
   set(H(k),'Color',cmap(k));
   set(H(k),'MarkerFaceColor',cmap(k));
   if ~isempty(varargin)
      set(H(k),varargin(1:2:end),varargin(2:2:end));
   end   
end

if nargout==0
    clear H
end

if d>2
   view(3);
end
