function [y,val] = gen_colormap(C, V, n, value_min, value_max)
%GEN_COLORMAP Generate a colormap going through specified points (ie colors)
%   GEN_COLORMAP(C) generates 100 points equally spaced between colors 
%   specified by rows of C.
%   GEN_COLORMAP(C, V) generates 100 points equally spaced between colors 
%   specified by rows of C, the vector V gives the values of each color.
%   GEN_COLORMAP(C, V,N) generates N points equally spaced between colors 
%   specified by rows of C, the vector V gives the values of each color.
%   GEN_COLORMAP(C, V,N,vmin,vmax) generates N points equally spaced between colors 
%   specified by rows of C, the vector V gives the values of each color. The range of values in the colormap 
%   are troncated between vim and vmax
%   [cmap,val] = GEN_COLORMAP(...) return colormap with the corresponding values
%
%   See also LOGSPACE, LINSPACE, :.

if nargin < 3
    n = 100;
end

[nc,d] = size(C);
y = [];
val = [];
steps = diff(V)/(max(V)-min(V))*n;

for i=1:nc-1
    step = ceil(steps(i));
    d1 = C(i,:);
    d2 = C(i+1,:);
    y = [y;ones(step-1,1)*d1+(0:step-2)'*(d2-d1)/(step-1)];
    val = [val;ones(step-1,1)*V(i)+(0:step-2)'*(V(i+1)-V(i))/(step-1)];
end
y = [y;C(end,:)];
val = [val;V(end)];

if nargin>3
    I = find(val>=value_min & val<=value_max);
    y = y(I,:);
    val = val(I);
end


