function [V,Xt] = ldaplot(celldata,varargin)
%LDAPLOT plots a linear projection of labelled data (discriminant directions)
%
%ldaplot(celldata)
%   plots points in a 2 dimensional axes
%   celldata is a cell array containing matrix with the same number of
%   columns (equal to the dimension)
%
%ldaplot(x,y,...)
%   x is a nxd matrix and y a vector of labels
%
%ldaplot(celldata,'dims',3)
%   plot 3-dimensional data
%
%ldaplot(celldata,...)
%ldaplot(x,y,...)
%   remaining arguments are passed to colplot
%
%[V,Xt] = ldaplot(celldata,...)
%   returns projection matrix V and transformed (Fisher) coordinates Xt
%
% Calls LBL2CELL, CELL2LBL, REDUCEDIM, COLPLOT
% 
% See also COLPLOT
 
if iscell(celldata)
    [X,y] = cell2lbl(celldata);
    labels = 1:length(data);
else
    X = celldata;
    y = varargin{1};
    varargin = varargin(2:end);
    celldata = lbl2cell(X,y);
end
K = length(celldata);
[n,d] = size(X);
if d==1
    X = [X zeros(n,1)];
end

dims = 2;
if ~isempty(varargin)
    if strcmp(varargin{1},'dims')
        dims = varargin{2};
        varargin = varargin(3:end);
    end
end

M = clustermeans(X,y);
[Z,V] = reducedim(X,y,dims);

colplot(Z,y,{'MarkerSize',6,varargin{:}})
colplot(M*V,1:K,{'Marker','o','MarkerSize',15,'MarkerEdgeColor',[0 0 0]})
view(dims);
%set(gca,'XTickLabel','','YTickLabel','','ZTickLabel','');
if nargout==0
    clear V
end
    