function st = mat2latex(mat,varargin)
% MAT2STRING - transform a matrix to a string
%
% str = mat2latex(M) transform the matrix (or cell array) into a string st containing the latex code 
%
% MAT2STRING(M,...,'fname',fname,...) save the code in the file fname.tex (fname is a string)
% MAT2STRING(M,...,'header',C,...) gives the headers of the columns in a cell array of strings
% MAT2STRING(M,...,'firstcol',F,...) specify the first column names in a cell array of strings
% MAT2STRING(M,...,'vlines',L,...) gives the index of the columns with a vertical bar
% MAT2STRING(M,...,'hlines',L,...) gives the index of the rows with a horizontal bar
% MAT2STRING(M,...,'boldlines',L,...) gives the index of the rows written in bold fonts
% MAT2STRING(M,...,'boldelements',L,...) gives the index of the elements written in bold fonts
%       L must be a 2 columns matrix giving row and lolumn of each bold
%       element
%
% See also TABULAR

[n,m] = size(mat);

fname = [];
header = cell(1,m);
firstcol = {};
hlines = [];
vlines = [];
boldlines=[];
boldelements=zeros(2,0);

if nargin>1
    for i=1:2:nargin-1
        switch(varargin{i})
            case 'fname'
                fname = varargin{i+1};
            case 'header'
                header = varargin{i+1};
            case 'vlines'
                vlines = varargin{i+1};
            case 'hlines'
                hlines = varargin{i+1};
            case 'firstcol'
                firstcol = varargin{i+1};
            case 'boldlines'
                boldlines = varargin{i+1};
            case 'boldelements'
                boldelements = varargin{i+1};
            otherwise
                error(['invalid argument name :' varargin{i}]);
        end
    end
end

if size(firstcol,2)>size(firstcol,1)
    firstcol = firstcol';
end
if size(header,2)<size(header,1)
    header = header';
end
if  ~isempty(firstcol) & size(firstcol,1)==length(hlines)+1
    headl = firstcol;
    firstcol = cell(size(mat,1),1);
    firstcol(1+[0 hlines(:)']) = headl;
end
if  ~isempty(firstcol) & size(firstcol,1)~=size(mat,1)
    error('The first column and the data matrix must have the same number of rows')
end


if  ~isempty(firstcol) & ~isempty(header) & size(header,2)-size(firstcol,2)~=size(mat,2)
    error('The  number of columns of the header is wrong')
end

m = m+ size(firstcol,2);

columns = '|l|';
% for j=2:m
%     if ismember(j,vlines)
%         columns = [columns 'c|'];
%     else
%         columns = [columns 'c'];
%     end
% end

%st = sprintf(['\\begin{tabular}{' columns '|}\n']);
st = '';

if isempty(header)
%     st = [st sprintf('\\hline\n')];
else
    nempt = floor((firstnonemptycell(header(:))-1)/size(header,1));
%     st = [st sprintf('\\cline{%d-%d}\n',nempt+1,m)];    
    for i=1:size(header,1)
        for j=1:m
            if j<nempt
%                     st = [st sprintf('\\multicolumn{1}{c}{} & ')];                
            elseif j==nempt
%                     st = [st sprintf('\\multicolumn{1}{c|}{} & ')];                
            else
                if j<=size(header,2) 
                    st = [st header{i,j}];
                end
                if j<m
%                     st = [st sprintf(' &\t')];
                else
                    st = [st sprintf('\n')];
                end
            end
        end
        if i==size(header,1)
%             st = [st sprintf('\\hlinen')];
        else
%             st = [st sprintf('\\cline{%d-%d}n',nempt+1,m)];    
        end
    end
end

for i=1:n    
    if ~isempty(firstcol) 
        if i<=size(firstcol,1)
            for j=1:size(firstcol,2)
                st = [st firstcol{i,j} ' '];  
            end
        else
            st = [st ' '];  
        end
    end
    for j=1:size(mat,2)
        if ismember(i,boldlines) | (~isempty(boldelements) & ismember([i,j],boldelements,'rows'))            
            bold=1;
            st = [st '*'];
        else
            bold=0;
        end
        if isnan(mat(i,j))
            st = [st ' '];
        elseif fpart(mat(i,j))==0
            st = [st sprintf('%.0f',mat(i,j))];
        else
            st = [st sprintf('%6.3f',mat(i,j))];
        end
        if bold
            st = [st '*'];
        end

        if j~=size(mat,2)
            st = [st sprintf(' ')];
        else
            st = [st sprintf('\n')];
        end    
        
    end    
    if ismember(i,hlines)
%         st = [st sprintf('\\hlinen')];
    end
    
end

% st = [st sprintf('\\hlinen')];

% st = [st sprintf(['\\end{tabular}n'])];








function x = firstnonemptycell(c)
%gives the index of the first non-empty cell of the cell array c
c=c(:);

for x=1:length(c);
    if ~isempty(c{x})
        return
    end
end

    
