function h = multnormplot(m,sigma,varargin);
%MULTNORMPLOT show a multidimensional gaussian distribution
%
% multnormplot(m,sigma);
% plot a gaussian density with mean m and covariance matrix sigma
% 
% h = multnormplot(m,sigma);
% return the handles of the lines from center to exterior
%
% h = multnormplot(m,sigma,'prop',q);
% defines the proportion of the density contained in the isocontours.
%
% h = multnormplot(m,sigma,'ncontours',nc);
% automatically defines the proportions to have nc contours.
%
% h = multnormplot(m,sigma,'rect',1);
% draws rectangles instead of ellipsoids.


prop = [];
ncontours = 3;
rect = 0;
draw_mean=1;
remarg={};

%%% PARAMETERS MANAGEMENT
for i=1:2:length(varargin)
    if ~isstr(varargin{i}) | ~exist(varargin{i},'var')
        remarg = varargin(i:end);
        break
    else
        eval([varargin{i} '= varargin{i+1};']);
    end    
end
%%%

if isempty(prop)
    prop =linspace(0,1,ncontours+2);
    prop=prop(2:end-1);
end

m=m(:);
d = length(m);

quant = sqrt(gaminv2(prop,d/2,2));

ncontours = length(quant);%number of circles
h =zeros(ncontours+1,1);

if d==2
    if draw_mean
        h(1) = line([m(1)],[m(2)],'Marker','o');
    end
    for i=1:ncontours
        np = i*30;
        if rect
            [V,D] = eig(sigma);D=diag(D);
            pos = quant(i)*[D(1)*[-1;-1;1;1;-1],D(2)*[-1;1;1;-1;-1]];
            pos = pos*V + ones(size(pos,1),1)*m';
        else %circle
            R = chol(sigma+eye(d)*1e-10);
            t = (0:np)'/np*2*pi;
            pos = [quant(i) * cos(t),...
                    quant(i) * sin(t)];
            pos = pos*R + ones(size(pos,1),1)*m';
        end      
        h(i+1) = line(pos(:,1),pos(:,2),'LineStyle','-');      
    end
    if ~isempty(remarg)
        set(h,remarg(1:2:end),remarg(2:2:end));
    end
    set(h(1),'MarkerFaceColor',min(1,get(h(1),'Color')*1.2+.1))
else   
    warning('dimension invalid for multnormplot function');
    
end


if nargout==0
    clear h;
end
